# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/FeatureSetSearch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/FeatureSetSearch.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\025FeatureSetSearchProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(featurestore/core/FeatureSetSearch.proto\x12\x11\x66\x65\x61turestore.core\"?\n\rTextualFilter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"T\n\x0fNumericalFilter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x10\n\x08operator\x18\x03 \x01(\t\x12\x11\n\taggregate\x18\x04 \x01(\t\"?\n\rBooleanFilter\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x12\x10\n\x08operator\x18\x03 \x01(\t\"\xdd\x01\n\x0f\x43ountCaseFilter\x12\x30\n\x04text\x18\x01 \x01(\x0b\x32 .featurestore.core.TextualFilterH\x00\x12\x35\n\x07numeric\x18\x02 \x01(\x0b\x32\".featurestore.core.NumericalFilterH\x00\x12\x33\n\x07\x62oolean\x18\x03 \x01(\x0b\x32 .featurestore.core.BooleanFilterH\x00\x12\x10\n\x08operator\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x05\x42\x0b\n\tcondition\"\xed\x01\n\x06\x46ilter\x12\x30\n\x04text\x18\x01 \x01(\x0b\x32 .featurestore.core.TextualFilterH\x00\x12\x35\n\x07numeric\x18\x02 \x01(\x0b\x32\".featurestore.core.NumericalFilterH\x00\x12\x33\n\x07\x62oolean\x18\x03 \x01(\x0b\x32 .featurestore.core.BooleanFilterH\x00\x12\x38\n\ncount_case\x18\x04 \x01(\x0b\x32\".featurestore.core.CountCaseFilterH\x00\x42\x0b\n\tcondition\"3\n\x05Query\x12*\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x19.featurestore.core.FilterB1\n\x18\x61i.h2o.featurestore.coreB\x15\x46\x65\x61tureSetSearchProtob\x06proto3'
)




_TEXTUALFILTER = _descriptor.Descriptor(
  name='TextualFilter',
  full_name='featurestore.core.TextualFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='featurestore.core.TextualFilter.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.TextualFilter.value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featurestore.core.TextualFilter.operator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=126,
)


_NUMERICALFILTER = _descriptor.Descriptor(
  name='NumericalFilter',
  full_name='featurestore.core.NumericalFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='featurestore.core.NumericalFilter.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.NumericalFilter.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featurestore.core.NumericalFilter.operator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='featurestore.core.NumericalFilter.aggregate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=212,
)


_BOOLEANFILTER = _descriptor.Descriptor(
  name='BooleanFilter',
  full_name='featurestore.core.BooleanFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='featurestore.core.BooleanFilter.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.BooleanFilter.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featurestore.core.BooleanFilter.operator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=277,
)


_COUNTCASEFILTER = _descriptor.Descriptor(
  name='CountCaseFilter',
  full_name='featurestore.core.CountCaseFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='featurestore.core.CountCaseFilter.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='featurestore.core.CountCaseFilter.numeric', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='featurestore.core.CountCaseFilter.boolean', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='featurestore.core.CountCaseFilter.operator', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.CountCaseFilter.value', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='condition', full_name='featurestore.core.CountCaseFilter.condition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=280,
  serialized_end=501,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='featurestore.core.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='featurestore.core.Filter.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='featurestore.core.Filter.numeric', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='featurestore.core.Filter.boolean', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_case', full_name='featurestore.core.Filter.count_case', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='condition', full_name='featurestore.core.Filter.condition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=504,
  serialized_end=741,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='featurestore.core.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='featurestore.core.Query.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=794,
)

_COUNTCASEFILTER.fields_by_name['text'].message_type = _TEXTUALFILTER
_COUNTCASEFILTER.fields_by_name['numeric'].message_type = _NUMERICALFILTER
_COUNTCASEFILTER.fields_by_name['boolean'].message_type = _BOOLEANFILTER
_COUNTCASEFILTER.oneofs_by_name['condition'].fields.append(
  _COUNTCASEFILTER.fields_by_name['text'])
_COUNTCASEFILTER.fields_by_name['text'].containing_oneof = _COUNTCASEFILTER.oneofs_by_name['condition']
_COUNTCASEFILTER.oneofs_by_name['condition'].fields.append(
  _COUNTCASEFILTER.fields_by_name['numeric'])
_COUNTCASEFILTER.fields_by_name['numeric'].containing_oneof = _COUNTCASEFILTER.oneofs_by_name['condition']
_COUNTCASEFILTER.oneofs_by_name['condition'].fields.append(
  _COUNTCASEFILTER.fields_by_name['boolean'])
_COUNTCASEFILTER.fields_by_name['boolean'].containing_oneof = _COUNTCASEFILTER.oneofs_by_name['condition']
_FILTER.fields_by_name['text'].message_type = _TEXTUALFILTER
_FILTER.fields_by_name['numeric'].message_type = _NUMERICALFILTER
_FILTER.fields_by_name['boolean'].message_type = _BOOLEANFILTER
_FILTER.fields_by_name['count_case'].message_type = _COUNTCASEFILTER
_FILTER.oneofs_by_name['condition'].fields.append(
  _FILTER.fields_by_name['text'])
_FILTER.fields_by_name['text'].containing_oneof = _FILTER.oneofs_by_name['condition']
_FILTER.oneofs_by_name['condition'].fields.append(
  _FILTER.fields_by_name['numeric'])
_FILTER.fields_by_name['numeric'].containing_oneof = _FILTER.oneofs_by_name['condition']
_FILTER.oneofs_by_name['condition'].fields.append(
  _FILTER.fields_by_name['boolean'])
_FILTER.fields_by_name['boolean'].containing_oneof = _FILTER.oneofs_by_name['condition']
_FILTER.oneofs_by_name['condition'].fields.append(
  _FILTER.fields_by_name['count_case'])
_FILTER.fields_by_name['count_case'].containing_oneof = _FILTER.oneofs_by_name['condition']
_QUERY.fields_by_name['filters'].message_type = _FILTER
DESCRIPTOR.message_types_by_name['TextualFilter'] = _TEXTUALFILTER
DESCRIPTOR.message_types_by_name['NumericalFilter'] = _NUMERICALFILTER
DESCRIPTOR.message_types_by_name['BooleanFilter'] = _BOOLEANFILTER
DESCRIPTOR.message_types_by_name['CountCaseFilter'] = _COUNTCASEFILTER
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextualFilter = _reflection.GeneratedProtocolMessageType('TextualFilter', (_message.Message,), {
  'DESCRIPTOR' : _TEXTUALFILTER,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.TextualFilter)
  })
_sym_db.RegisterMessage(TextualFilter)

NumericalFilter = _reflection.GeneratedProtocolMessageType('NumericalFilter', (_message.Message,), {
  'DESCRIPTOR' : _NUMERICALFILTER,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.NumericalFilter)
  })
_sym_db.RegisterMessage(NumericalFilter)

BooleanFilter = _reflection.GeneratedProtocolMessageType('BooleanFilter', (_message.Message,), {
  'DESCRIPTOR' : _BOOLEANFILTER,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.BooleanFilter)
  })
_sym_db.RegisterMessage(BooleanFilter)

CountCaseFilter = _reflection.GeneratedProtocolMessageType('CountCaseFilter', (_message.Message,), {
  'DESCRIPTOR' : _COUNTCASEFILTER,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CountCaseFilter)
  })
_sym_db.RegisterMessage(CountCaseFilter)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Filter)
  })
_sym_db.RegisterMessage(Filter)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'featurestore.core.FeatureSetSearch_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Query)
  })
_sym_db.RegisterMessage(Query)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
