# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featurestore/core/CoreService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from featurestore.core import FeatureSetSearch_pb2 as featurestore_dot_core_dot_FeatureSetSearch__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='featurestore/core/CoreService.proto',
  package='featurestore.core',
  syntax='proto3',
  serialized_options=b'\n\030ai.h2o.featurestore.coreB\020CoreServiceProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#featurestore/core/CoreService.proto\x12\x11\x66\x65\x61turestore.core\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a(featurestore/core/FeatureSetSearch.proto\"E\n\x17\x46\x65\x61tureSetExistsRequest\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\"M\n\x17GetIngestHistoryRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\"*\n\x14ProjectExistsRequest\x12\x12\n\nproject_id\x18\x02 \x01(\t\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\")\n\x17ProjectsDefaultResponse\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"P\n\x1eHasPermissionToRetrieveRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\"B\n\x1fHasPermissionToRetrieveResponse\x12\x1f\n\x17has_retrieve_permission\x18\x01 \x01(\x08\"d\n\x1bStartRevertIngestJobRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x11\n\tingest_id\x18\x02 \x01(\t\"e\n\x12OnlineRetrieveMeta\x12\x17\n\x0f\x62\x61se_online_url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"%\n\x14GetUserByMailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"G\n\x15GetUserByMailResponse\x12.\n\x04user\x18\x01 \x01(\x0b\x32 .featurestore.core.UserBasicInfo\" \n\x0cTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\"N\n\x14GenerateTokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x65xpiry_date\x18\x03 \x01(\t\"F\n\rTokenResponse\x12\x35\n\x05token\x18\x01 \x01(\x0b\x32&.featurestore.core.PersonalAccessToken\"L\n\x12ListTokensResponse\x12\x36\n\x06tokens\x18\x01 \x03(\x0b\x32&.featurestore.core.PersonalAccessToken\"!\n\x10RawTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x83\x01\n\x0fListJobsRequest\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12,\n\x08job_type\x18\x03 \x01(\x0e\x32\x1a.featurestore.core.JobType\"8\n\x10ListJobsResponse\x12$\n\x04jobs\x18\x01 \x03(\x0b\x32\x16.featurestore.core.Job\"\x17\n\x05JobId\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"Q\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12,\n\x08job_type\x18\x02 \x01(\x0e\x32\x1a.featurestore.core.JobType\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\"6\n\x10JobProgressInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x12\n\nnext_index\x18\x02 \x01(\x05\"#\n\x11JobProgressOutput\x12\x0e\n\x06status\x18\x01 \x03(\t\"\x9d\x01\n\x1b\x46\x65\x61tureSetPermissionRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12\x35\n\npermission\x18\x03 \x01(\x0e\x32!.featurestore.core.PermissionType\"\x93\x01\n\x18ProjectPermissionRequest\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12\x35\n\npermission\x18\x03 \x01(\x0e\x32!.featurestore.core.PermissionType\"\x8b\x01\n\x1cStartExtractSchemaJobRequest\x12=\n\x11raw_data_location\x18\x01 \x01(\x0b\x32\".featurestore.core.RawDataLocation\x12,\n\x04\x63red\x18\x02 \x01(\x0b\x32\x1e.featurestore.core.Credentials\"I\n\x15\x45xtractSchemaResponse\x12\x30\n\x06schema\x18\x01 \x03(\x0b\x32 .featurestore.core.FeatureSchema\"S\n\x1dListFeatureSetsVersionRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\"H\n\x12\x46\x65\x61tureSetResponse\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\">\n\x0fProjectResponse\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\"U\n\x1fUpdateFeatureSetMetadataRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\"I\n\rLoginResponse\x12\x13\n\tlogin_url\x18\x01 \x01(\tH\x00\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"G\n\x15GetActiveUserResponse\x12.\n\x04user\x18\x01 \x01(\x0b\x32 .featurestore.core.UserBasicInfo\")\n\x11GetProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\"M\n\x17\x44\x65leteFeatureSetRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"8\n\rUserBasicInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"`\n\x04User\x12\x39\n\x0fuser_basic_info\x18\x01 \x01(\x0b\x32 .featurestore.core.UserBasicInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\r\n\x05roles\x18\x03 \x03(\t\"y\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x03\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x12\n\ntoken_type\x18\x05 \x01(\t\"C\n\x14\x44\x65leteProjectRequest\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\"K\n\x1cUpdateProjectMetadataRequest\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\"a\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x0e\n\x06locked\x18\x04 \x01(\x08\"\\\n\x15\x43reateProjectResponse\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\x12\x16\n\x0e\x61lready_exists\x18\x02 \x01(\x08\"D\n\x14ListProjectsResponse\x12,\n\x08projects\x18\x01 \x03(\x0b\x32\x1a.featurestore.core.Project\"W\n\x18GetIngestHistoryResponse\x12;\n\x0eingest_history\x18\x01 \x03(\x0b\x32#.featurestore.core.FeatureSetIngest\"n\n\x16ListFeatureSetsRequest\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\x12\'\n\x05query\x18\x02 \x01(\x0b\x32\x18.featurestore.core.Query\"a\n\x0e\x41WSCredentials\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x14\n\x0csecret_token\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\"\xa6\x01\n\x10\x41zureCredentials\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x11\n\tsas_token\x18\x03 \x01(\t\x12\x15\n\rsas_container\x18\x04 \x01(\t\x12\x14\n\x0csp_client_id\x18\x05 \x01(\t\x12\x14\n\x0csp_tenant_id\x18\x06 \x01(\t\x12\x11\n\tsp_secret\x18\x07 \x01(\t\"6\n\x14SnowflakeCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"1\n\x0fJDBCCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x87\x02\n\x0b\x43redentials\x12.\n\x03\x61ws\x18\x01 \x01(\x0b\x32!.featurestore.core.AWSCredentials\x12\x32\n\x05\x61zure\x18\x02 \x01(\x0b\x32#.featurestore.core.AzureCredentials\x12:\n\tsnowflake\x18\x03 \x01(\x0b\x32\'.featurestore.core.SnowflakeCredentials\x12\x39\n\rjdbc_database\x18\x04 \x01(\x0b\x32\".featurestore.core.JDBCCredentials\x12\x1d\n\x15\x64riverless_ai_license\x18\x05 \x01(\t\"N\n\x17ListFeatureSetsResponse\x12\x33\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\x1d.featurestore.core.FeatureSet\"c\n\x1eListFeatureSetVersionsResponse\x12\x41\n\x08versions\x18\x01 \x03(\x0b\x32/.featurestore.core.FeatureSetVersionDescription\"~\n\x1c\x46\x65\x61tureSetVersionDescription\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x16\n\x0eversion_change\x18\x02 \x01(\t\x12\x35\n\x11\x63reated_date_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x14GetFeatureSetRequest\x12+\n\x07project\x18\x01 \x01(\x0b\x32\x1a.featurestore.core.Project\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x88\x02\n\x15StartIngestJobRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12,\n\x04\x63red\x18\x02 \x01(\x0b\x32\x1e.featurestore.core.Credentials\x12\x17\n\x0fstart_date_time\x18\x03 \x01(\t\x12\x15\n\rend_date_time\x18\x04 \x01(\t\x12$\n\x1cnew_version_on_schema_change\x18\x05 \x01(\x08\x12\x37\n\x0b\x64\x61ta_source\x18\x06 \x01(\x0b\x32\".featurestore.core.RawDataLocation\"\xac\x02\n\x0eIngestResponse\x12:\n\x04meta\x18\x01 \x01(\x0b\x32,.featurestore.core.IngestResponse.IngestMeta\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x1a\xa9\x01\n\nIngestMeta\x12\x16\n\x0e\x63\x61\x63he_location\x18\x01 \x01(\t\x12\x1a\n\x12raw_cache_location\x18\x02 \x01(\t\x12\x37\n\x13ingestion_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0cingest_scope\x18\x04 \x01(\x0b\x32\x18.featurestore.core.Scope\"\x9c\x01\n\x0fRetrieveRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x17\n\x0fstart_date_time\x18\x02 \x01(\t\x12\x15\n\rend_date_time\x18\x03 \x01(\t\x12\x11\n\tingest_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\"c\n\x17RetrieveAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\x12\x30\n\x0eretrieve_scope\x18\x02 \x01(\x0b\x32\x18.featurestore.core.Scope\"\xed\x01\n\x17RetrieveAsSparkResponse\x12\x12\n\ncache_path\x18\x01 \x01(\t\x12H\n\x07options\x18\x02 \x03(\x0b\x32\x37.featurestore.core.RetrieveAsSparkResponse.OptionsEntry\x12\x30\n\x0eretrieve_scope\x18\x03 \x01(\x0b\x32\x18.featurestore.core.Scope\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x0ePreviewRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x17\n\x0fstart_date_time\x18\x02 \x01(\t\x12\x15\n\rend_date_time\x18\x03 \x01(\t\x12\x10\n\x08num_rows\x18\x04 \x01(\x05\"3\n\x0fPreviewResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x10\n\x08num_rows\x18\x02 \x01(\x05\"2\n\x1cIngestWriteCredentialRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xc1\x01\n\x1dIngestWriteCredentialResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12N\n\x07options\x18\x02 \x03(\x0b\x32=.featurestore.core.IngestWriteCredentialResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x06\n\x0fRawDataLocation\x12-\n\x03\x63sv\x18\x01 \x01(\x0b\x32\x1e.featurestore.core.CSVFileSpecH\x00\x12\x35\n\x07parquet\x18\x02 \x01(\x0b\x32\".featurestore.core.ParquetFileSpecH\x00\x12:\n\tsnowflake\x18\x03 \x01(\x0b\x32%.featurestore.core.SnowflakeTableSpecH\x00\x12\x30\n\x04jdbc\x18\x04 \x01(\x0b\x32 .featurestore.core.JDBCTableSpecH\x00\x12\x37\n\x04mojo\x18\x05 \x01(\x0b\x32\'.featurestore.core.DriverlessAIMOJOSpecH\x00\x12>\n\x0espark_pipeline\x18\x06 \x01(\x0b\x32$.featurestore.core.SparkPipelineSpecH\x00\x12/\n\x04json\x18\x07 \x01(\x0b\x32\x1f.featurestore.core.JSONFileSpecH\x00\x12\x38\n\x0b\x64\x65lta_table\x18\x08 \x01(\x0b\x32!.featurestore.core.DeltaTableSpecH\x00\x12G\n\x13joined_feature_sets\x18\t \x01(\x0b\x32(.featurestore.core.JoinedFeatureSetsSpecH\x00\x12\x36\n\ncsv_folder\x18\n \x01(\x0b\x32 .featurestore.core.CSVFolderSpecH\x00\x12>\n\x0eparquet_folder\x18\x0b \x01(\x0b\x32$.featurestore.core.ParquetFolderSpecH\x00\x12\x38\n\x0bjson_folder\x18\x0c \x01(\x0b\x32!.featurestore.core.JSONFolderSpecH\x00\x12>\n\x0ctemp_parquet\x18\r \x01(\x0b\x32&.featurestore.core.TempParquetFileSpecH\x00\x42\x08\n\x06source\"\x84\x01\n\x15JoinedFeatureSetsSpec\x12+\n\x04left\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12,\n\x05right\x18\x02 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x10\n\x08join_key\x18\x03 \x01(\t\"`\n\x14\x44riverlessAIMOJOSpec\x12,\n\x05input\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04mojo\x18\x03 \x01(\t\".\n\x0b\x43SVFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\t\"/\n\x0cJSONFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmultiline\x18\x02 \x01(\x08\"\x1f\n\x0fParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"#\n\x13TempParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"C\n\x05Proxy\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\"\xce\x01\n\x12SnowflakeTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x11\n\twarehouse\x18\x05 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08insecure\x18\x07 \x01(\x08\x12\'\n\x05proxy\x18\x08 \x01(\x0b\x32\x18.featurestore.core.Proxy\x12\x0c\n\x04role\x18\t \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\"\xb5\x01\n\rJDBCTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnection_url\x18\x03 \x01(\t\x12\x16\n\x0enum_partitions\x18\x04 \x01(\x05\x12\x18\n\x10partition_column\x18\x05 \x01(\t\x12\x13\n\x0blower_bound\x18\x06 \x01(\x04\x12\x13\n\x0bupper_bound\x18\x07 \x01(\x04\x12\x12\n\nfetch_size\x18\x08 \x01(\x05\"a\n\x11SparkPipelineSpec\x12,\n\x05input\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08pipeline\x18\x03 \x01(\t\"m\n\x0e\x44\x65ltaTableSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12)\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x19.featurestore.core.Filter\"R\n\rCSVFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x19\n\x11partition_pattern\x18\x02 \x01(\t\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"C\n\x11ParquetFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x19\n\x11partition_pattern\x18\x02 \x01(\t\"S\n\x0eJSONFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x19\n\x11partition_pattern\x18\x02 \x01(\t\x12\x11\n\tmultiline\x18\x03 \x01(\x08\"\x96\r\n\nFeatureSet\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x16\n\x0eversion_change\x18\x05 \x01(\t\x12\x1a\n\x12time_travel_column\x18\x06 \x01(\t\x12!\n\x19time_travel_column_format\x18\x07 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\x08 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12/\n\x05owner\x18\n \x01(\x0b\x32 .featurestore.core.UserBasicInfo\x12\x30\n\x06\x61uthor\x18\x0b \x01(\x0b\x32 .featurestore.core.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12\x45\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32&.featurestore.core.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12>\n\x0ctime_to_live\x18\x16 \x01(\x0b\x32(.featurestore.core.FeatureSet.TimeToLive\x12,\n\x08\x66\x65\x61tures\x18\x17 \x03(\x0b\x32\x1a.featurestore.core.Feature\x12<\n\nstatistics\x18\x18 \x01(\x0b\x32(.featurestore.core.FeatureSet.Statistics\x12?\n\x0cspecial_data\x18\x19 \x01(\x0b\x32).featurestore.core.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x1a \x01(\t\x12\x15\n\rsecondary_key\x18\x1b \x01(\t\x12\n\n\x02id\x18\x1c \x01(\t\x12\x33\n\x11time_travel_scope\x18\x1d \x01(\x0b\x32\x18.featurestore.core.Scope\x12\x16\n\x0e\x61pplication_id\x18\x1e \x01(\t\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\x1f \x01(\t\x12\x34\n\x06online\x18  \x01(\x0b\x32$.featurestore.core.FeatureSet.Online\x12\x0e\n\x06secret\x18! \x01(\x08\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x14\n\x0cpartition_by\x18# \x03(\t\x12,\n\x0b\x63ustom_data\x18$ \x01(\x0b\x32\x17.google.protobuf.Struct\x1ap\n\nTimeToLive\x12\x13\n\x0bttl_offline\x18\x01 \x01(\x05\x12\x1c\n\x14ttl_offline_interval\x18\x02 \x01(\t\x12\x12\n\nttl_online\x18\x03 \x01(\x05\x12\x1b\n\x13ttl_online_interval\x18\x04 \x01(\t\x1a\"\n\nStatistics\x12\x14\n\x0c\x64\x61ta_latency\x18\x01 \x01(\x05\x1a\xe6\x01\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12>\n\x05legal\x18\x05 \x01(\x0b\x32/.featurestore.core.FeatureSet.SpecialData.Legal\x1a[\n\x05Legal\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\x12\x31\n\rapproved_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05notes\x18\x03 \x01(\t\x1aJ\n\x06Online\x12\x18\n\x10online_namespace\x18\x01 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"o\n\x05Scope\x12\x33\n\x0fstart_date_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa2\x06\n\x19RegisterFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12+\n\x07project\x18\x02 \x01(\x0b\x32\x1a.featurestore.core.Project\x12\x1a\n\x12time_travel_column\x18\x03 \x01(\t\x12!\n\x19time_travel_column_format\x18\x04 \x01(\t\x12\x13\n\x0bprimary_key\x18\x05 \x01(\t\x12\x15\n\rsecondary_key\x18\x06 \x01(\t\x12\x30\n\x06schema\x18\x07 \x03(\x0b\x32 .featurestore.core.FeatureSchema\x12\x0e\n\x06secret\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x17\n\x0fmasked_features\x18\n \x03(\t\x12\x14\n\x0cpartition_by\x18\x0b \x03(\t\x12\'\n\x1ftime_travel_column_as_partition\x18\x0c \x01(\x08\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\r \x01(\t\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\x0e \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x0f \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x10 \x01(\t\x12\x34\n\x06online\x18\x11 \x01(\x0b\x32$.featurestore.core.FeatureSet.Online\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x12 \x03(\t\x12\x0c\n\x04tags\x18\x13 \x03(\t\x12\x18\n\x10process_interval\x18\x14 \x01(\r\x12\x45\n\x15process_interval_unit\x18\x15 \x01(\x0e\x32&.featurestore.core.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x16 \x01(\t\x12?\n\x0cspecial_data\x18\x17 \x01(\x0b\x32).featurestore.core.FeatureSet.SpecialData\x12,\n\x0b\x63ustom_data\x18\x18 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xb4\x01\n!CreateNewFeatureSetVersionRequest\x12\x32\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\x1d.featurestore.core.FeatureSet\x12\x30\n\x06schema\x18\x02 \x03(\x0b\x32 .featurestore.core.FeatureSchema\x12\x19\n\x11\x61\x66\x66\x65\x63ted_features\x18\x03 \x03(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\xa6\x01\n\x0e\x46\x65\x61tureProfile\x12\x14\n\x0c\x66\x65\x61ture_type\x18\x01 \x01(\t\x12\x44\n\x0b\x63\x61tegorical\x18\x02 \x01(\x0b\x32/.featurestore.core.CategoricalFeatureStatistics\x12\x38\n\nstatistics\x18\x03 \x01(\x0b\x32$.featurestore.core.FeatureStatistics\"0\n\rFeatureSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\"\xac\x03\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0eversion_change\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\x12\x32\n\x07profile\x18\x06 \x01(\x0b\x32!.featurestore.core.FeatureProfile\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\nimportance\x18\x08 \x01(\x01\x12\x0f\n\x07special\x18\t \x01(\t\x12\x39\n\nmonitoring\x18\n \x01(\x0b\x32%.featurestore.core.Feature.Monitoring\x12\x33\n\x0fnested_features\x18\x0b \x03(\x0b\x32\x1a.featurestore.core.Feature\x12$\n\x1c\x64\x61ta_type_hierarchical_paths\x18\x0c \x03(\t\x12\x1a\n\x12marked_for_masking\x18\r \x01(\x08\x1a\'\n\nMonitoring\x12\x19\n\x11\x61nomaly_detection\x18\x01 \x01(\x08\"\xac\x01\n\x11\x46\x65\x61tureStatistics\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0e\n\x06median\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x18\n\x10stddev_rec_count\x18\x06 \x01(\x03\x12\x12\n\nnull_count\x18\x07 \x01(\x03\x12\x11\n\tnan_count\x18\x08 \x01(\x03\x12\x0e\n\x06unique\x18\t \x01(\x03\"\xa2\x01\n\x1c\x43\x61tegoricalFeatureStatistics\x12\x0e\n\x06unique\x18\x01 \x01(\x03\x12G\n\x03top\x18\x02 \x03(\x0b\x32:.featurestore.core.CategoricalFeatureStatistics.FeatureTop\x1a)\n\nFeatureTop\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"\xad\x02\n\x07Project\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x05owner\x18\x03 \x01(\x0b\x32 .featurestore.core.UserBasicInfo\x12\x30\n\x06\x61uthor\x18\x04 \x01(\x0b\x32 .featurestore.core.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0e\n\x06locked\x18\x08 \x01(\x08\x12\n\n\x02id\x18\t \x01(\t\"\xed\x01\n\x10\x46\x65\x61tureSetIngest\x12\x11\n\tingest_id\x18\x01 \x01(\t\x12\x34\n\x10ingest_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x06source\x18\x03 \x01(\x0b\x32\".featurestore.core.RawDataLocation\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x05 \x01(\t\x12\'\n\x05scope\x18\x06 \x01(\x0b\x32\x18.featurestore.core.Scope\"\xd7\x01\n\x13PersonalAccessToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12-\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65xpiry_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*s\n\x07JobType\x12\n\n\x06Ingest\x10\x00\x12\x0c\n\x08Retrieve\x10\x01\x12\x11\n\rExtractSchema\x10\x02\x12\x0b\n\x07Preview\x10\x03\x12\x15\n\x11\x43omputeStatistics\x10\x04\x12\n\n\x06Revert\x10\x05\x12\x0b\n\x07Unknown\x10\x06*L\n\x0ePermissionType\x12\t\n\x05Owner\x10\x00\x12\n\n\x06\x45\x64itor\x10\x01\x12\x0c\n\x08\x43onsumer\x10\x02\x12\x15\n\x11SensitiveConsumer\x10\x03*\x96\x01\n\x0f\x46\x65\x61tureDataType\x12\x0b\n\x07TinyInt\x10\x00\x12\x0c\n\x08SmallInt\x10\x01\x12\n\n\x06\x42igInt\x10\x02\x12\x07\n\x03Int\x10\x03\x12\t\n\x05\x46loat\x10\x04\x12\n\n\x06\x44ouble\x10\x05\x12\n\n\x06String\x10\x06\x12\n\n\x06\x42inary\x10\x07\x12\x0b\n\x07\x42oolean\x10\x08\x12\x08\n\x04\x44\x61te\x10\t\x12\r\n\tTimestamp\x10\n*E\n\x0b\x46\x65\x61tureType\x12\r\n\tNumerical\x10\x00\x12\x0f\n\x0b\x43\x61tegorical\x10\x01\x12\x0c\n\x08Temporal\x10\x02\x12\x08\n\x04Text\x10\x03*b\n\x13ProcessIntervalUnit\x12\t\n\x05HOURS\x10\x00\x12\n\n\x06MONTHS\x10\x01\x12\x08\n\x04\x44\x41YS\x10\x02\x12\x0b\n\x07MINUTES\x10\x03\x12\x0b\n\x07SECONDS\x10\x04\x12\x10\n\x0cMILLISECONDS\x10\x05\x32\xfb\"\n\x0b\x43oreService\x12S\n\x08ListJobs\x12\".featurestore.core.ListJobsRequest\x1a#.featurestore.core.ListJobsResponse\x12:\n\x06GetJob\x12\x18.featurestore.core.JobId\x1a\x16.featurestore.core.Job\x12[\n\x0eGetJobProgress\x12#.featurestore.core.JobProgressInput\x1a$.featurestore.core.JobProgressOutput\x12\x62\n\x15StartExtractSchemaJob\x12/.featurestore.core.StartExtractSchemaJobRequest\x1a\x18.featurestore.core.JobId\x12_\n\x19GetExtractSchemaJobOutput\x12\x18.featurestore.core.JobId\x1a(.featurestore.core.ExtractSchemaResponse\x12T\n\x0eStartIngestJob\x12(.featurestore.core.StartIngestJobRequest\x1a\x18.featurestore.core.JobId\x12Q\n\x12GetIngestJobOutput\x12\x18.featurestore.core.JobId\x1a!.featurestore.core.IngestResponse\x12W\n\x17StartRetrieveAsLinksJob\x12\".featurestore.core.RetrieveRequest\x1a\x18.featurestore.core.JobId\x12\x63\n\x1bGetRetrieveAsLinksJobOutput\x12\x18.featurestore.core.JobId\x1a*.featurestore.core.RetrieveAsLinksResponse\x12\x61\n\x0fRetrieveAsSpark\x12\".featurestore.core.RetrieveRequest\x1a*.featurestore.core.RetrieveAsSparkResponse\x12N\n\x0fStartPreviewJob\x12!.featurestore.core.PreviewRequest\x1a\x18.featurestore.core.JobId\x12S\n\x13GetPreviewJobOutput\x12\x18.featurestore.core.JobId\x1a\".featurestore.core.PreviewResponse\x12~\n\x19GetIngestWriteCredentials\x12/.featurestore.core.IngestWriteCredentialRequest\x1a\x30.featurestore.core.IngestWriteCredentialResponse\x12`\n\x14StartRevertIngestJob\x12..featurestore.core.StartRevertIngestJobRequest\x1a\x18.featurestore.core.JobId\x12L\n\x18GetRevertIngestJobOutput\x12\x18.featurestore.core.JobId\x1a\x16.google.protobuf.Empty\x12\x80\x01\n\x17HasPermissionToRetrieve\x12\x31.featurestore.core.HasPermissionToRetrieveRequest\x1a\x32.featurestore.core.HasPermissionToRetrieveResponse\x12i\n\x12RegisterFeatureSet\x12,.featurestore.core.RegisterFeatureSetRequest\x1a%.featurestore.core.FeatureSetResponse\x12y\n\x1a\x43reateNewFeatureSetVersion\x12\x34.featurestore.core.CreateNewFeatureSetVersionRequest\x1a%.featurestore.core.FeatureSetResponse\x12V\n\x15GetOnlineRetrieveMeta\x12\x16.google.protobuf.Empty\x1a%.featurestore.core.OnlineRetrieveMeta\x12u\n\x18UpdateFeatureSetMetadata\x12\x32.featurestore.core.UpdateFeatureSetMetadataRequest\x1a%.featurestore.core.FeatureSetResponse\x12K\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a%.featurestore.core.GetVersionResponse\x12_\n\rGetFeatureSet\x12\'.featurestore.core.GetFeatureSetRequest\x1a%.featurestore.core.FeatureSetResponse\x12}\n\x16ListFeatureSetVersions\x12\x30.featurestore.core.ListFeatureSetsVersionRequest\x1a\x31.featurestore.core.ListFeatureSetVersionsResponse\x12V\n\x10\x44\x65leteFeatureSet\x12*.featurestore.core.DeleteFeatureSetRequest\x1a\x16.google.protobuf.Empty\x12h\n\x0fListFeatureSets\x12).featurestore.core.ListFeatureSetsRequest\x1a*.featurestore.core.ListFeatureSetsResponse\x12\x61\n\x10\x46\x65\x61tureSetExists\x12*.featurestore.core.FeatureSetExistsRequest\x1a!.featurestore.core.ExistsResponse\x12k\n\x10GetIngestHistory\x12*.featurestore.core.GetIngestHistoryRequest\x1a+.featurestore.core.GetIngestHistoryResponse\x12O\n\x0cListProjects\x12\x16.google.protobuf.Empty\x1a\'.featurestore.core.ListProjectsResponse\x12\x62\n\rCreateProject\x12\'.featurestore.core.CreateProjectRequest\x1a(.featurestore.core.CreateProjectResponse\x12V\n\nGetProject\x12$.featurestore.core.GetProjectRequest\x1a\".featurestore.core.ProjectResponse\x12P\n\rDeleteProject\x12\'.featurestore.core.DeleteProjectRequest\x1a\x16.google.protobuf.Empty\x12l\n\x15UpdateProjectMetadata\x12/.featurestore.core.UpdateProjectMetadataRequest\x1a\".featurestore.core.ProjectResponse\x12X\n\x12GetProjectsDefault\x12\x16.google.protobuf.Empty\x1a*.featurestore.core.ProjectsDefaultResponse\x12[\n\rProjectExists\x12\'.featurestore.core.ProjectExistsRequest\x1a!.featurestore.core.ExistsResponse\x12`\n\x0eGetAccessToken\x12&.featurestore.core.RefreshTokenRequest\x1a&.featurestore.core.AccessTokenResponse\x12\x62\n\rGetUserByMail\x12\'.featurestore.core.GetUserByMailRequest\x1a(.featurestore.core.GetUserByMailResponse\x12\x42\n\x06Logout\x12 .featurestore.core.LogoutRequest\x1a\x16.google.protobuf.Empty\x12Q\n\rGetActiveUser\x12\x16.google.protobuf.Empty\x1a(.featurestore.core.GetActiveUserResponse\x12\x43\n\x05Login\x12\x16.google.protobuf.Empty\x1a .featurestore.core.LoginResponse0\x01\x12p\n\x17\x41\x64\x64\x46\x65\x61tureSetPermission\x12..featurestore.core.FeatureSetPermissionRequest\x1a%.featurestore.core.FeatureSetResponse\x12g\n\x14\x41\x64\x64ProjectPermission\x12+.featurestore.core.ProjectPermissionRequest\x1a\".featurestore.core.ProjectResponse\x12s\n\x1aRemoveFeatureSetPermission\x12..featurestore.core.FeatureSetPermissionRequest\x1a%.featurestore.core.FeatureSetResponse\x12j\n\x17RemoveProjectPermission\x12+.featurestore.core.ProjectPermissionRequest\x1a\".featurestore.core.ProjectResponse\x12\x46\n\x0bRevokeToken\x12\x1f.featurestore.core.TokenRequest\x1a\x16.google.protobuf.Empty\x12]\n\rGenerateToken\x12\'.featurestore.core.GenerateTokenRequest\x1a#.featurestore.core.RawTokenResponse\x12K\n\nListTokens\x12\x16.google.protobuf.Empty\x1a%.featurestore.core.ListTokensResponse\x12M\n\x08GetToken\x12\x1f.featurestore.core.TokenRequest\x1a .featurestore.core.TokenResponseB,\n\x18\x61i.h2o.featurestore.coreB\x10\x43oreServiceProtob\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,featurestore_dot_core_dot_FeatureSetSearch__pb2.DESCRIPTOR,])

_JOBTYPE = _descriptor.EnumDescriptor(
  name='JobType',
  full_name='featurestore.core.JobType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Ingest', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Retrieve', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExtractSchema', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Preview', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ComputeStatistics', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Revert', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12950,
  serialized_end=13065,
)
_sym_db.RegisterEnumDescriptor(_JOBTYPE)

JobType = enum_type_wrapper.EnumTypeWrapper(_JOBTYPE)
_PERMISSIONTYPE = _descriptor.EnumDescriptor(
  name='PermissionType',
  full_name='featurestore.core.PermissionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Owner', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Editor', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Consumer', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SensitiveConsumer', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13067,
  serialized_end=13143,
)
_sym_db.RegisterEnumDescriptor(_PERMISSIONTYPE)

PermissionType = enum_type_wrapper.EnumTypeWrapper(_PERMISSIONTYPE)
_FEATUREDATATYPE = _descriptor.EnumDescriptor(
  name='FeatureDataType',
  full_name='featurestore.core.FeatureDataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TinyInt', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SmallInt', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BigInt', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Int', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Float', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Double', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='String', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Binary', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Boolean', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Date', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Timestamp', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13146,
  serialized_end=13296,
)
_sym_db.RegisterEnumDescriptor(_FEATUREDATATYPE)

FeatureDataType = enum_type_wrapper.EnumTypeWrapper(_FEATUREDATATYPE)
_FEATURETYPE = _descriptor.EnumDescriptor(
  name='FeatureType',
  full_name='featurestore.core.FeatureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Numerical', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Categorical', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Temporal', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Text', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13298,
  serialized_end=13367,
)
_sym_db.RegisterEnumDescriptor(_FEATURETYPE)

FeatureType = enum_type_wrapper.EnumTypeWrapper(_FEATURETYPE)
_PROCESSINTERVALUNIT = _descriptor.EnumDescriptor(
  name='ProcessIntervalUnit',
  full_name='featurestore.core.ProcessIntervalUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HOURS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAYS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLISECONDS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13369,
  serialized_end=13467,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINTERVALUNIT)

ProcessIntervalUnit = enum_type_wrapper.EnumTypeWrapper(_PROCESSINTERVALUNIT)
Ingest = 0
Retrieve = 1
ExtractSchema = 2
Preview = 3
ComputeStatistics = 4
Revert = 5
Unknown = 6
Owner = 0
Editor = 1
Consumer = 2
SensitiveConsumer = 3
TinyInt = 0
SmallInt = 1
BigInt = 2
Int = 3
Float = 4
Double = 5
String = 6
Binary = 7
Boolean = 8
Date = 9
Timestamp = 10
Numerical = 0
Categorical = 1
Temporal = 2
Text = 3
HOURS = 0
MONTHS = 1
DAYS = 2
MINUTES = 3
SECONDS = 4
MILLISECONDS = 5



_FEATURESETEXISTSREQUEST = _descriptor.Descriptor(
  name='FeatureSetExistsRequest',
  full_name='featurestore.core.FeatureSetExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='featurestore.core.FeatureSetExistsRequest.project_id', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='featurestore.core.FeatureSetExistsRequest.feature_set_id', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=261,
)


_GETINGESTHISTORYREQUEST = _descriptor.Descriptor(
  name='GetIngestHistoryRequest',
  full_name='featurestore.core.GetIngestHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.GetIngestHistoryRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=340,
)


_PROJECTEXISTSREQUEST = _descriptor.Descriptor(
  name='ProjectExistsRequest',
  full_name='featurestore.core.ProjectExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='featurestore.core.ProjectExistsRequest.project_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=384,
)


_EXISTSRESPONSE = _descriptor.Descriptor(
  name='ExistsResponse',
  full_name='featurestore.core.ExistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='featurestore.core.ExistsResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=418,
)


_PROJECTSDEFAULTRESPONSE = _descriptor.Descriptor(
  name='ProjectsDefaultResponse',
  full_name='featurestore.core.ProjectsDefaultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locked', full_name='featurestore.core.ProjectsDefaultResponse.locked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=461,
)


_HASPERMISSIONTORETRIEVEREQUEST = _descriptor.Descriptor(
  name='HasPermissionToRetrieveRequest',
  full_name='featurestore.core.HasPermissionToRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='featurestore.core.HasPermissionToRetrieveRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='featurestore.core.HasPermissionToRetrieveRequest.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=543,
)


_HASPERMISSIONTORETRIEVERESPONSE = _descriptor.Descriptor(
  name='HasPermissionToRetrieveResponse',
  full_name='featurestore.core.HasPermissionToRetrieveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_retrieve_permission', full_name='featurestore.core.HasPermissionToRetrieveResponse.has_retrieve_permission', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=611,
)


_STARTREVERTINGESTJOBREQUEST = _descriptor.Descriptor(
  name='StartRevertIngestJobRequest',
  full_name='featurestore.core.StartRevertIngestJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.StartRevertIngestJobRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='featurestore.core.StartRevertIngestJobRequest.ingest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=713,
)


_ONLINERETRIEVEMETA = _descriptor.Descriptor(
  name='OnlineRetrieveMeta',
  full_name='featurestore.core.OnlineRetrieveMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_online_url', full_name='featurestore.core.OnlineRetrieveMeta.base_online_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='featurestore.core.OnlineRetrieveMeta.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='featurestore.core.OnlineRetrieveMeta.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='featurestore.core.OnlineRetrieveMeta.is_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=816,
)


_REFRESHTOKENREQUEST = _descriptor.Descriptor(
  name='RefreshTokenRequest',
  full_name='featurestore.core.RefreshTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='featurestore.core.RefreshTokenRequest.refresh_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=862,
)


_GETUSERBYMAILREQUEST = _descriptor.Descriptor(
  name='GetUserByMailRequest',
  full_name='featurestore.core.GetUserByMailRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='featurestore.core.GetUserByMailRequest.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=901,
)


_GETUSERBYMAILRESPONSE = _descriptor.Descriptor(
  name='GetUserByMailResponse',
  full_name='featurestore.core.GetUserByMailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='featurestore.core.GetUserByMailResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=974,
)


_TOKENREQUEST = _descriptor.Descriptor(
  name='TokenRequest',
  full_name='featurestore.core.TokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_id', full_name='featurestore.core.TokenRequest.token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1008,
)


_GENERATETOKENREQUEST = _descriptor.Descriptor(
  name='GenerateTokenRequest',
  full_name='featurestore.core.GenerateTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.GenerateTokenRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.GenerateTokenRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='featurestore.core.GenerateTokenRequest.expiry_date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1088,
)


_TOKENRESPONSE = _descriptor.Descriptor(
  name='TokenResponse',
  full_name='featurestore.core.TokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='featurestore.core.TokenResponse.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1160,
)


_LISTTOKENSRESPONSE = _descriptor.Descriptor(
  name='ListTokensResponse',
  full_name='featurestore.core.ListTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='featurestore.core.ListTokensResponse.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1238,
)


_RAWTOKENRESPONSE = _descriptor.Descriptor(
  name='RawTokenResponse',
  full_name='featurestore.core.RawTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='featurestore.core.RawTokenResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1240,
  serialized_end=1273,
)


_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='featurestore.core.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='featurestore.core.ListJobsRequest.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.ListJobsRequest.feature_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_type', full_name='featurestore.core.ListJobsRequest.job_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1407,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='featurestore.core.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobs', full_name='featurestore.core.ListJobsResponse.jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1465,
)


_JOBID = _descriptor.Descriptor(
  name='JobId',
  full_name='featurestore.core.JobId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='featurestore.core.JobId.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1490,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='featurestore.core.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='featurestore.core.Job.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_type', full_name='featurestore.core.Job.job_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='featurestore.core.Job.done', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1492,
  serialized_end=1573,
)


_JOBPROGRESSINPUT = _descriptor.Descriptor(
  name='JobProgressInput',
  full_name='featurestore.core.JobProgressInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='featurestore.core.JobProgressInput.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_index', full_name='featurestore.core.JobProgressInput.next_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=1629,
)


_JOBPROGRESSOUTPUT = _descriptor.Descriptor(
  name='JobProgressOutput',
  full_name='featurestore.core.JobProgressOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='featurestore.core.JobProgressOutput.status', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1666,
)


_FEATURESETPERMISSIONREQUEST = _descriptor.Descriptor(
  name='FeatureSetPermissionRequest',
  full_name='featurestore.core.FeatureSetPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.FeatureSetPermissionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_emails', full_name='featurestore.core.FeatureSetPermissionRequest.user_emails', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='featurestore.core.FeatureSetPermissionRequest.permission', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1669,
  serialized_end=1826,
)


_PROJECTPERMISSIONREQUEST = _descriptor.Descriptor(
  name='ProjectPermissionRequest',
  full_name='featurestore.core.ProjectPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.ProjectPermissionRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_emails', full_name='featurestore.core.ProjectPermissionRequest.user_emails', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='featurestore.core.ProjectPermissionRequest.permission', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1976,
)


_STARTEXTRACTSCHEMAJOBREQUEST = _descriptor.Descriptor(
  name='StartExtractSchemaJobRequest',
  full_name='featurestore.core.StartExtractSchemaJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_data_location', full_name='featurestore.core.StartExtractSchemaJobRequest.raw_data_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cred', full_name='featurestore.core.StartExtractSchemaJobRequest.cred', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2118,
)


_EXTRACTSCHEMARESPONSE = _descriptor.Descriptor(
  name='ExtractSchemaResponse',
  full_name='featurestore.core.ExtractSchemaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='featurestore.core.ExtractSchemaResponse.schema', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2193,
)


_LISTFEATURESETSVERSIONREQUEST = _descriptor.Descriptor(
  name='ListFeatureSetsVersionRequest',
  full_name='featurestore.core.ListFeatureSetsVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.ListFeatureSetsVersionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2195,
  serialized_end=2278,
)


_FEATURESETRESPONSE = _descriptor.Descriptor(
  name='FeatureSetResponse',
  full_name='featurestore.core.FeatureSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.FeatureSetResponse.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2280,
  serialized_end=2352,
)


_PROJECTRESPONSE = _descriptor.Descriptor(
  name='ProjectResponse',
  full_name='featurestore.core.ProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.ProjectResponse.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2416,
)


_UPDATEFEATURESETMETADATAREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureSetMetadataRequest',
  full_name='featurestore.core.UpdateFeatureSetMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.UpdateFeatureSetMetadataRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2418,
  serialized_end=2503,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='featurestore.core.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_url', full_name='featurestore.core.LoginResponse.login_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='featurestore.core.LoginResponse.refresh_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='featurestore.core.LoginResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2505,
  serialized_end=2578,
)


_GETACTIVEUSERRESPONSE = _descriptor.Descriptor(
  name='GetActiveUserResponse',
  full_name='featurestore.core.GetActiveUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='featurestore.core.GetActiveUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2580,
  serialized_end=2651,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='featurestore.core.GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='featurestore.core.GetProjectRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2653,
  serialized_end=2694,
)


_DELETEFEATURESETREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureSetRequest',
  full_name='featurestore.core.DeleteFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.DeleteFeatureSetRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2773,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='featurestore.core.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='featurestore.core.LogoutRequest.refresh_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2775,
  serialized_end=2813,
)


_USERBASICINFO = _descriptor.Descriptor(
  name='UserBasicInfo',
  full_name='featurestore.core.UserBasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featurestore.core.UserBasicInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.UserBasicInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='featurestore.core.UserBasicInfo.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2815,
  serialized_end=2871,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='featurestore.core.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_basic_info', full_name='featurestore.core.User.user_basic_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='featurestore.core.User.groups', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='featurestore.core.User.roles', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2873,
  serialized_end=2969,
)


_ACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='AccessTokenResponse',
  full_name='featurestore.core.AccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='featurestore.core.AccessTokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='featurestore.core.AccessTokenResponse.refresh_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='featurestore.core.AccessTokenResponse.expires_in', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='featurestore.core.AccessTokenResponse.scope', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='featurestore.core.AccessTokenResponse.token_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3092,
)


_DELETEPROJECTREQUEST = _descriptor.Descriptor(
  name='DeleteProjectRequest',
  full_name='featurestore.core.DeleteProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.DeleteProjectRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3094,
  serialized_end=3161,
)


_UPDATEPROJECTMETADATAREQUEST = _descriptor.Descriptor(
  name='UpdateProjectMetadataRequest',
  full_name='featurestore.core.UpdateProjectMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.UpdateProjectMetadataRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3238,
)


_CREATEPROJECTREQUEST = _descriptor.Descriptor(
  name='CreateProjectRequest',
  full_name='featurestore.core.CreateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='featurestore.core.CreateProjectRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.CreateProjectRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='featurestore.core.CreateProjectRequest.secret', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='featurestore.core.CreateProjectRequest.locked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3240,
  serialized_end=3337,
)


_CREATEPROJECTRESPONSE = _descriptor.Descriptor(
  name='CreateProjectResponse',
  full_name='featurestore.core.CreateProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.CreateProjectResponse.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='already_exists', full_name='featurestore.core.CreateProjectResponse.already_exists', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3339,
  serialized_end=3431,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='featurestore.core.ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='featurestore.core.ListProjectsResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3433,
  serialized_end=3501,
)


_GETINGESTHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetIngestHistoryResponse',
  full_name='featurestore.core.GetIngestHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingest_history', full_name='featurestore.core.GetIngestHistoryResponse.ingest_history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3503,
  serialized_end=3590,
)


_LISTFEATURESETSREQUEST = _descriptor.Descriptor(
  name='ListFeatureSetsRequest',
  full_name='featurestore.core.ListFeatureSetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.ListFeatureSetsRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featurestore.core.ListFeatureSetsRequest.query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3592,
  serialized_end=3702,
)


_AWSCREDENTIALS = _descriptor.Descriptor(
  name='AWSCredentials',
  full_name='featurestore.core.AWSCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='featurestore.core.AWSCredentials.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_token', full_name='featurestore.core.AWSCredentials.secret_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='featurestore.core.AWSCredentials.region', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_name', full_name='featurestore.core.AWSCredentials.bucket_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3704,
  serialized_end=3801,
)


_AZURECREDENTIALS = _descriptor.Descriptor(
  name='AzureCredentials',
  full_name='featurestore.core.AzureCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_name', full_name='featurestore.core.AzureCredentials.account_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_key', full_name='featurestore.core.AzureCredentials.account_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sas_token', full_name='featurestore.core.AzureCredentials.sas_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sas_container', full_name='featurestore.core.AzureCredentials.sas_container', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_client_id', full_name='featurestore.core.AzureCredentials.sp_client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_tenant_id', full_name='featurestore.core.AzureCredentials.sp_tenant_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_secret', full_name='featurestore.core.AzureCredentials.sp_secret', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3804,
  serialized_end=3970,
)


_SNOWFLAKECREDENTIALS = _descriptor.Descriptor(
  name='SnowflakeCredentials',
  full_name='featurestore.core.SnowflakeCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='featurestore.core.SnowflakeCredentials.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='featurestore.core.SnowflakeCredentials.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3972,
  serialized_end=4026,
)


_JDBCCREDENTIALS = _descriptor.Descriptor(
  name='JDBCCredentials',
  full_name='featurestore.core.JDBCCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='featurestore.core.JDBCCredentials.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='featurestore.core.JDBCCredentials.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4077,
)


_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='featurestore.core.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='featurestore.core.Credentials.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azure', full_name='featurestore.core.Credentials.azure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='featurestore.core.Credentials.snowflake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jdbc_database', full_name='featurestore.core.Credentials.jdbc_database', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driverless_ai_license', full_name='featurestore.core.Credentials.driverless_ai_license', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4080,
  serialized_end=4343,
)


_LISTFEATURESETSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetsResponse',
  full_name='featurestore.core.ListFeatureSetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_sets', full_name='featurestore.core.ListFeatureSetsResponse.feature_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4345,
  serialized_end=4423,
)


_LISTFEATURESETVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetVersionsResponse',
  full_name='featurestore.core.ListFeatureSetVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='featurestore.core.ListFeatureSetVersionsResponse.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4425,
  serialized_end=4524,
)


_FEATURESETVERSIONDESCRIPTION = _descriptor.Descriptor(
  name='FeatureSetVersionDescription',
  full_name='featurestore.core.FeatureSetVersionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.FeatureSetVersionDescription.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='featurestore.core.FeatureSetVersionDescription.version_change', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='featurestore.core.FeatureSetVersionDescription.created_date_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4526,
  serialized_end=4652,
)


_GETFEATURESETREQUEST = _descriptor.Descriptor(
  name='GetFeatureSetRequest',
  full_name='featurestore.core.GetFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.GetFeatureSetRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='featurestore.core.GetFeatureSetRequest.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.GetFeatureSetRequest.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4654,
  serialized_end=4764,
)


_STARTINGESTJOBREQUEST = _descriptor.Descriptor(
  name='StartIngestJobRequest',
  full_name='featurestore.core.StartIngestJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.StartIngestJobRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cred', full_name='featurestore.core.StartIngestJobRequest.cred', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='featurestore.core.StartIngestJobRequest.start_date_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='featurestore.core.StartIngestJobRequest.end_date_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_version_on_schema_change', full_name='featurestore.core.StartIngestJobRequest.new_version_on_schema_change', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source', full_name='featurestore.core.StartIngestJobRequest.data_source', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4767,
  serialized_end=5031,
)


_INGESTRESPONSE_INGESTMETA = _descriptor.Descriptor(
  name='IngestMeta',
  full_name='featurestore.core.IngestResponse.IngestMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_location', full_name='featurestore.core.IngestResponse.IngestMeta.cache_location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_cache_location', full_name='featurestore.core.IngestResponse.IngestMeta.raw_cache_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingestion_timestamp', full_name='featurestore.core.IngestResponse.IngestMeta.ingestion_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_scope', full_name='featurestore.core.IngestResponse.IngestMeta.ingest_scope', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5165,
  serialized_end=5334,
)

_INGESTRESPONSE = _descriptor.Descriptor(
  name='IngestResponse',
  full_name='featurestore.core.IngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='featurestore.core.IngestResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.IngestResponse.feature_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INGESTRESPONSE_INGESTMETA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5034,
  serialized_end=5334,
)


_RETRIEVEREQUEST = _descriptor.Descriptor(
  name='RetrieveRequest',
  full_name='featurestore.core.RetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.RetrieveRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='featurestore.core.RetrieveRequest.start_date_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='featurestore.core.RetrieveRequest.end_date_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='featurestore.core.RetrieveRequest.ingest_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='featurestore.core.RetrieveRequest.session_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5337,
  serialized_end=5493,
)


_RETRIEVEASLINKSRESPONSE = _descriptor.Descriptor(
  name='RetrieveAsLinksResponse',
  full_name='featurestore.core.RetrieveAsLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_links', full_name='featurestore.core.RetrieveAsLinksResponse.download_links', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve_scope', full_name='featurestore.core.RetrieveAsLinksResponse.retrieve_scope', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5495,
  serialized_end=5594,
)


_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='featurestore.core.RetrieveAsSparkResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featurestore.core.RetrieveAsSparkResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.RetrieveAsSparkResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=5834,
)

_RETRIEVEASSPARKRESPONSE = _descriptor.Descriptor(
  name='RetrieveAsSparkResponse',
  full_name='featurestore.core.RetrieveAsSparkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_path', full_name='featurestore.core.RetrieveAsSparkResponse.cache_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='featurestore.core.RetrieveAsSparkResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve_scope', full_name='featurestore.core.RetrieveAsSparkResponse.retrieve_scope', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='featurestore.core.RetrieveAsSparkResponse.session_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5597,
  serialized_end=5834,
)


_PREVIEWREQUEST = _descriptor.Descriptor(
  name='PreviewRequest',
  full_name='featurestore.core.PreviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.PreviewRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='featurestore.core.PreviewRequest.start_date_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='featurestore.core.PreviewRequest.end_date_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='featurestore.core.PreviewRequest.num_rows', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5837,
  serialized_end=5971,
)


_PREVIEWRESPONSE = _descriptor.Descriptor(
  name='PreviewResponse',
  full_name='featurestore.core.PreviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='featurestore.core.PreviewResponse.result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='featurestore.core.PreviewResponse.num_rows', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5973,
  serialized_end=6024,
)


_INGESTWRITECREDENTIALREQUEST = _descriptor.Descriptor(
  name='IngestWriteCredentialRequest',
  full_name='featurestore.core.IngestWriteCredentialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='featurestore.core.IngestWriteCredentialRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6026,
  serialized_end=6076,
)


_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='featurestore.core.IngestWriteCredentialResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='featurestore.core.IngestWriteCredentialResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='featurestore.core.IngestWriteCredentialResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=5834,
)

_INGESTWRITECREDENTIALRESPONSE = _descriptor.Descriptor(
  name='IngestWriteCredentialResponse',
  full_name='featurestore.core.IngestWriteCredentialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.IngestWriteCredentialResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='featurestore.core.IngestWriteCredentialResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='featurestore.core.IngestWriteCredentialResponse.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6079,
  serialized_end=6272,
)


_RAWDATALOCATION = _descriptor.Descriptor(
  name='RawDataLocation',
  full_name='featurestore.core.RawDataLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='csv', full_name='featurestore.core.RawDataLocation.csv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='featurestore.core.RawDataLocation.parquet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='featurestore.core.RawDataLocation.snowflake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jdbc', full_name='featurestore.core.RawDataLocation.jdbc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mojo', full_name='featurestore.core.RawDataLocation.mojo', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_pipeline', full_name='featurestore.core.RawDataLocation.spark_pipeline', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='featurestore.core.RawDataLocation.json', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_table', full_name='featurestore.core.RawDataLocation.delta_table', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joined_feature_sets', full_name='featurestore.core.RawDataLocation.joined_feature_sets', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csv_folder', full_name='featurestore.core.RawDataLocation.csv_folder', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_folder', full_name='featurestore.core.RawDataLocation.parquet_folder', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_folder', full_name='featurestore.core.RawDataLocation.json_folder', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_parquet', full_name='featurestore.core.RawDataLocation.temp_parquet', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='featurestore.core.RawDataLocation.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6275,
  serialized_end=7057,
)


_JOINEDFEATURESETSSPEC = _descriptor.Descriptor(
  name='JoinedFeatureSetsSpec',
  full_name='featurestore.core.JoinedFeatureSetsSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='featurestore.core.JoinedFeatureSetsSpec.left', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='featurestore.core.JoinedFeatureSetsSpec.right', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key', full_name='featurestore.core.JoinedFeatureSetsSpec.join_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7060,
  serialized_end=7192,
)


_DRIVERLESSAIMOJOSPEC = _descriptor.Descriptor(
  name='DriverlessAIMOJOSpec',
  full_name='featurestore.core.DriverlessAIMOJOSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='featurestore.core.DriverlessAIMOJOSpec.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='featurestore.core.DriverlessAIMOJOSpec.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mojo', full_name='featurestore.core.DriverlessAIMOJOSpec.mojo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7194,
  serialized_end=7290,
)


_CSVFILESPEC = _descriptor.Descriptor(
  name='CSVFileSpec',
  full_name='featurestore.core.CSVFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.CSVFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='featurestore.core.CSVFileSpec.delimiter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7292,
  serialized_end=7338,
)


_JSONFILESPEC = _descriptor.Descriptor(
  name='JSONFileSpec',
  full_name='featurestore.core.JSONFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.JSONFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiline', full_name='featurestore.core.JSONFileSpec.multiline', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7340,
  serialized_end=7387,
)


_PARQUETFILESPEC = _descriptor.Descriptor(
  name='ParquetFileSpec',
  full_name='featurestore.core.ParquetFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.ParquetFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7389,
  serialized_end=7420,
)


_TEMPPARQUETFILESPEC = _descriptor.Descriptor(
  name='TempParquetFileSpec',
  full_name='featurestore.core.TempParquetFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.TempParquetFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7422,
  serialized_end=7457,
)


_PROXY = _descriptor.Descriptor(
  name='Proxy',
  full_name='featurestore.core.Proxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='featurestore.core.Proxy.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='featurestore.core.Proxy.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='featurestore.core.Proxy.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='featurestore.core.Proxy.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7459,
  serialized_end=7526,
)


_SNOWFLAKETABLESPEC = _descriptor.Descriptor(
  name='SnowflakeTableSpec',
  full_name='featurestore.core.SnowflakeTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='featurestore.core.SnowflakeTableSpec.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='featurestore.core.SnowflakeTableSpec.database', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='featurestore.core.SnowflakeTableSpec.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featurestore.core.SnowflakeTableSpec.query', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warehouse', full_name='featurestore.core.SnowflakeTableSpec.warehouse', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='featurestore.core.SnowflakeTableSpec.schema', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insecure', full_name='featurestore.core.SnowflakeTableSpec.insecure', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy', full_name='featurestore.core.SnowflakeTableSpec.proxy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='featurestore.core.SnowflakeTableSpec.role', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='featurestore.core.SnowflakeTableSpec.account', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7529,
  serialized_end=7735,
)


_JDBCTABLESPEC = _descriptor.Descriptor(
  name='JDBCTableSpec',
  full_name='featurestore.core.JDBCTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='featurestore.core.JDBCTableSpec.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='featurestore.core.JDBCTableSpec.query', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_url', full_name='featurestore.core.JDBCTableSpec.connection_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_partitions', full_name='featurestore.core.JDBCTableSpec.num_partitions', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_column', full_name='featurestore.core.JDBCTableSpec.partition_column', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_bound', full_name='featurestore.core.JDBCTableSpec.lower_bound', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_bound', full_name='featurestore.core.JDBCTableSpec.upper_bound', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fetch_size', full_name='featurestore.core.JDBCTableSpec.fetch_size', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7738,
  serialized_end=7919,
)


_SPARKPIPELINESPEC = _descriptor.Descriptor(
  name='SparkPipelineSpec',
  full_name='featurestore.core.SparkPipelineSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='featurestore.core.SparkPipelineSpec.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='featurestore.core.SparkPipelineSpec.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='featurestore.core.SparkPipelineSpec.pipeline', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7921,
  serialized_end=8018,
)


_DELTATABLESPEC = _descriptor.Descriptor(
  name='DeltaTableSpec',
  full_name='featurestore.core.DeltaTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='featurestore.core.DeltaTableSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.DeltaTableSpec.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='featurestore.core.DeltaTableSpec.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='featurestore.core.DeltaTableSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8020,
  serialized_end=8129,
)


_CSVFOLDERSPEC = _descriptor.Descriptor(
  name='CSVFolderSpec',
  full_name='featurestore.core.CSVFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='featurestore.core.CSVFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_pattern', full_name='featurestore.core.CSVFolderSpec.partition_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='featurestore.core.CSVFolderSpec.delimiter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8131,
  serialized_end=8213,
)


_PARQUETFOLDERSPEC = _descriptor.Descriptor(
  name='ParquetFolderSpec',
  full_name='featurestore.core.ParquetFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='featurestore.core.ParquetFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_pattern', full_name='featurestore.core.ParquetFolderSpec.partition_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8215,
  serialized_end=8282,
)


_JSONFOLDERSPEC = _descriptor.Descriptor(
  name='JSONFolderSpec',
  full_name='featurestore.core.JSONFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='featurestore.core.JSONFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_pattern', full_name='featurestore.core.JSONFolderSpec.partition_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiline', full_name='featurestore.core.JSONFolderSpec.multiline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8284,
  serialized_end=8367,
)


_FEATURESET_TIMETOLIVE = _descriptor.Descriptor(
  name='TimeToLive',
  full_name='featurestore.core.FeatureSet.TimeToLive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ttl_offline', full_name='featurestore.core.FeatureSet.TimeToLive.ttl_offline', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_offline_interval', full_name='featurestore.core.FeatureSet.TimeToLive.ttl_offline_interval', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_online', full_name='featurestore.core.FeatureSet.TimeToLive.ttl_online', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_online_interval', full_name='featurestore.core.FeatureSet.TimeToLive.ttl_online_interval', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9599,
  serialized_end=9711,
)

_FEATURESET_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='featurestore.core.FeatureSet.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_latency', full_name='featurestore.core.FeatureSet.Statistics.data_latency', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9713,
  serialized_end=9747,
)

_FEATURESET_SPECIALDATA_LEGAL = _descriptor.Descriptor(
  name='Legal',
  full_name='featurestore.core.FeatureSet.SpecialData.Legal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='approved', full_name='featurestore.core.FeatureSet.SpecialData.Legal.approved', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approved_date', full_name='featurestore.core.FeatureSet.SpecialData.Legal.approved_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='featurestore.core.FeatureSet.SpecialData.Legal.notes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9889,
  serialized_end=9980,
)

_FEATURESET_SPECIALDATA = _descriptor.Descriptor(
  name='SpecialData',
  full_name='featurestore.core.FeatureSet.SpecialData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spi', full_name='featurestore.core.FeatureSet.SpecialData.spi', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pci', full_name='featurestore.core.FeatureSet.SpecialData.pci', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rpi', full_name='featurestore.core.FeatureSet.SpecialData.rpi', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='demographic', full_name='featurestore.core.FeatureSet.SpecialData.demographic', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal', full_name='featurestore.core.FeatureSet.SpecialData.legal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESET_SPECIALDATA_LEGAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9750,
  serialized_end=9980,
)

_FEATURESET_ONLINE = _descriptor.Descriptor(
  name='Online',
  full_name='featurestore.core.FeatureSet.Online',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online_namespace', full_name='featurestore.core.FeatureSet.Online.online_namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_type', full_name='featurestore.core.FeatureSet.Online.connection_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='featurestore.core.FeatureSet.Online.topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9982,
  serialized_end=10056,
)

_FEATURESET = _descriptor.Descriptor(
  name='FeatureSet',
  full_name='featurestore.core.FeatureSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.FeatureSet.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='featurestore.core.FeatureSet.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.FeatureSet.version', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='featurestore.core.FeatureSet.version_change', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column', full_name='featurestore.core.FeatureSet.time_travel_column', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_format', full_name='featurestore.core.FeatureSet.time_travel_column_format', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_type', full_name='featurestore.core.FeatureSet.feature_set_type', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.FeatureSet.description', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='featurestore.core.FeatureSet.owner', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='featurestore.core.FeatureSet.author', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='featurestore.core.FeatureSet.created_date_time', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='featurestore.core.FeatureSet.last_update_date_time', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='featurestore.core.FeatureSet.application_name', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='featurestore.core.FeatureSet.deprecated', index=13,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_date', full_name='featurestore.core.FeatureSet.deprecated_date', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_domains', full_name='featurestore.core.FeatureSet.data_source_domains', index=15,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='featurestore.core.FeatureSet.tags', index=16,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval', full_name='featurestore.core.FeatureSet.process_interval', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval_unit', full_name='featurestore.core.FeatureSet.process_interval_unit', index=18,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='featurestore.core.FeatureSet.flow', index=19,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='featurestore.core.FeatureSet.time_to_live', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='featurestore.core.FeatureSet.features', index=21,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='featurestore.core.FeatureSet.statistics', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='featurestore.core.FeatureSet.special_data', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='featurestore.core.FeatureSet.primary_key', index=24,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_key', full_name='featurestore.core.FeatureSet.secondary_key', index=25,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='featurestore.core.FeatureSet.id', index=26,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_scope', full_name='featurestore.core.FeatureSet.time_travel_scope', index=27,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='featurestore.core.FeatureSet.application_id', index=28,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_state', full_name='featurestore.core.FeatureSet.feature_set_state', index=29,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='featurestore.core.FeatureSet.online', index=30,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='featurestore.core.FeatureSet.secret', index=31,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='featurestore.core.FeatureSet.project_id', index=32,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='featurestore.core.FeatureSet.partition_by', index=33,
      number=35, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='featurestore.core.FeatureSet.custom_data', index=34,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESET_TIMETOLIVE, _FEATURESET_STATISTICS, _FEATURESET_SPECIALDATA, _FEATURESET_ONLINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8370,
  serialized_end=10056,
)


_SCOPE = _descriptor.Descriptor(
  name='Scope',
  full_name='featurestore.core.Scope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='featurestore.core.Scope.start_date_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='featurestore.core.Scope.end_date_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10058,
  serialized_end=10169,
)


_REGISTERFEATURESETREQUEST = _descriptor.Descriptor(
  name='RegisterFeatureSetRequest',
  full_name='featurestore.core.RegisterFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='featurestore.core.RegisterFeatureSetRequest.feature_set_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='featurestore.core.RegisterFeatureSetRequest.project', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column', full_name='featurestore.core.RegisterFeatureSetRequest.time_travel_column', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_format', full_name='featurestore.core.RegisterFeatureSetRequest.time_travel_column_format', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='featurestore.core.RegisterFeatureSetRequest.primary_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_key', full_name='featurestore.core.RegisterFeatureSetRequest.secondary_key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='featurestore.core.RegisterFeatureSetRequest.schema', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='featurestore.core.RegisterFeatureSetRequest.secret', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.RegisterFeatureSetRequest.description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='masked_features', full_name='featurestore.core.RegisterFeatureSetRequest.masked_features', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='featurestore.core.RegisterFeatureSetRequest.partition_by', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_as_partition', full_name='featurestore.core.RegisterFeatureSetRequest.time_travel_column_as_partition', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_type', full_name='featurestore.core.RegisterFeatureSetRequest.feature_set_type', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_state', full_name='featurestore.core.RegisterFeatureSetRequest.feature_set_state', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='featurestore.core.RegisterFeatureSetRequest.application_name', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='featurestore.core.RegisterFeatureSetRequest.application_id', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='featurestore.core.RegisterFeatureSetRequest.online', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_domains', full_name='featurestore.core.RegisterFeatureSetRequest.data_source_domains', index=17,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='featurestore.core.RegisterFeatureSetRequest.tags', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval', full_name='featurestore.core.RegisterFeatureSetRequest.process_interval', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval_unit', full_name='featurestore.core.RegisterFeatureSetRequest.process_interval_unit', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='featurestore.core.RegisterFeatureSetRequest.flow', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='featurestore.core.RegisterFeatureSetRequest.special_data', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='featurestore.core.RegisterFeatureSetRequest.custom_data', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10172,
  serialized_end=10974,
)


_CREATENEWFEATURESETVERSIONREQUEST = _descriptor.Descriptor(
  name='CreateNewFeatureSetVersionRequest',
  full_name='featurestore.core.CreateNewFeatureSetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='featurestore.core.CreateNewFeatureSetVersionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='featurestore.core.CreateNewFeatureSetVersionRequest.schema', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_features', full_name='featurestore.core.CreateNewFeatureSetVersionRequest.affected_features', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='featurestore.core.CreateNewFeatureSetVersionRequest.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10977,
  serialized_end=11157,
)


_FEATUREPROFILE = _descriptor.Descriptor(
  name='FeatureProfile',
  full_name='featurestore.core.FeatureProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='featurestore.core.FeatureProfile.feature_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categorical', full_name='featurestore.core.FeatureProfile.categorical', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='featurestore.core.FeatureProfile.statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11160,
  serialized_end=11326,
)


_FEATURESCHEMA = _descriptor.Descriptor(
  name='FeatureSchema',
  full_name='featurestore.core.FeatureSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.FeatureSchema.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='featurestore.core.FeatureSchema.data_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11328,
  serialized_end=11376,
)


_FEATURE_MONITORING = _descriptor.Descriptor(
  name='Monitoring',
  full_name='featurestore.core.Feature.Monitoring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anomaly_detection', full_name='featurestore.core.Feature.Monitoring.anomaly_detection', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11768,
  serialized_end=11807,
)

_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='featurestore.core.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.Feature.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.Feature.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='featurestore.core.Feature.version_change', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='featurestore.core.Feature.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='featurestore.core.Feature.data_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='featurestore.core.Feature.profile', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.Feature.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importance', full_name='featurestore.core.Feature.importance', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special', full_name='featurestore.core.Feature.special', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='featurestore.core.Feature.monitoring', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_features', full_name='featurestore.core.Feature.nested_features', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type_hierarchical_paths', full_name='featurestore.core.Feature.data_type_hierarchical_paths', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marked_for_masking', full_name='featurestore.core.Feature.marked_for_masking', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURE_MONITORING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11379,
  serialized_end=11807,
)


_FEATURESTATISTICS = _descriptor.Descriptor(
  name='FeatureStatistics',
  full_name='featurestore.core.FeatureStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max', full_name='featurestore.core.FeatureStatistics.max', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='featurestore.core.FeatureStatistics.mean', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='featurestore.core.FeatureStatistics.median', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='featurestore.core.FeatureStatistics.min', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='featurestore.core.FeatureStatistics.stddev', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_rec_count', full_name='featurestore.core.FeatureStatistics.stddev_rec_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_count', full_name='featurestore.core.FeatureStatistics.null_count', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nan_count', full_name='featurestore.core.FeatureStatistics.nan_count', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique', full_name='featurestore.core.FeatureStatistics.unique', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11810,
  serialized_end=11982,
)


_CATEGORICALFEATURESTATISTICS_FEATURETOP = _descriptor.Descriptor(
  name='FeatureTop',
  full_name='featurestore.core.CategoricalFeatureStatistics.FeatureTop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.CategoricalFeatureStatistics.FeatureTop.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='featurestore.core.CategoricalFeatureStatistics.FeatureTop.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12106,
  serialized_end=12147,
)

_CATEGORICALFEATURESTATISTICS = _descriptor.Descriptor(
  name='CategoricalFeatureStatistics',
  full_name='featurestore.core.CategoricalFeatureStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique', full_name='featurestore.core.CategoricalFeatureStatistics.unique', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='featurestore.core.CategoricalFeatureStatistics.top', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORICALFEATURESTATISTICS_FEATURETOP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11985,
  serialized_end=12147,
)


_GETVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetVersionResponse',
  full_name='featurestore.core.GetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='featurestore.core.GetVersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12149,
  serialized_end=12186,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='featurestore.core.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.Project.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.Project.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='featurestore.core.Project.owner', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='featurestore.core.Project.author', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='featurestore.core.Project.created_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='featurestore.core.Project.last_update_date_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='featurestore.core.Project.secret', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='featurestore.core.Project.locked', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='featurestore.core.Project.id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12189,
  serialized_end=12490,
)


_FEATURESETINGEST = _descriptor.Descriptor(
  name='FeatureSetIngest',
  full_name='featurestore.core.FeatureSetIngest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='featurestore.core.FeatureSetIngest.ingest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_timestamp', full_name='featurestore.core.FeatureSetIngest.ingest_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='featurestore.core.FeatureSetIngest.source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='featurestore.core.FeatureSetIngest.feature_set_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='featurestore.core.FeatureSetIngest.feature_set_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='featurestore.core.FeatureSetIngest.scope', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12493,
  serialized_end=12730,
)


_PERSONALACCESSTOKEN = _descriptor.Descriptor(
  name='PersonalAccessToken',
  full_name='featurestore.core.PersonalAccessToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='featurestore.core.PersonalAccessToken.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='featurestore.core.PersonalAccessToken.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='featurestore.core.PersonalAccessToken.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_used', full_name='featurestore.core.PersonalAccessToken.last_used', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_time', full_name='featurestore.core.PersonalAccessToken.creation_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='featurestore.core.PersonalAccessToken.expiry_date', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12733,
  serialized_end=12948,
)

_GETINGESTHISTORYREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_STARTREVERTINGESTJOBREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_GETUSERBYMAILRESPONSE.fields_by_name['user'].message_type = _USERBASICINFO
_TOKENRESPONSE.fields_by_name['token'].message_type = _PERSONALACCESSTOKEN
_LISTTOKENSRESPONSE.fields_by_name['tokens'].message_type = _PERSONALACCESSTOKEN
_LISTJOBSREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_LISTJOBSREQUEST.fields_by_name['job_type'].enum_type = _JOBTYPE
_LISTJOBSRESPONSE.fields_by_name['jobs'].message_type = _JOB
_JOB.fields_by_name['job_type'].enum_type = _JOBTYPE
_FEATURESETPERMISSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_FEATURESETPERMISSIONREQUEST.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_PROJECTPERMISSIONREQUEST.fields_by_name['project'].message_type = _PROJECT
_PROJECTPERMISSIONREQUEST.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['raw_data_location'].message_type = _RAWDATALOCATION
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['cred'].message_type = _CREDENTIALS
_EXTRACTSCHEMARESPONSE.fields_by_name['schema'].message_type = _FEATURESCHEMA
_LISTFEATURESETSVERSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_FEATURESETRESPONSE.fields_by_name['feature_set'].message_type = _FEATURESET
_PROJECTRESPONSE.fields_by_name['project'].message_type = _PROJECT
_UPDATEFEATURESETMETADATAREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_LOGINRESPONSE.oneofs_by_name['response'].fields.append(
  _LOGINRESPONSE.fields_by_name['login_url'])
_LOGINRESPONSE.fields_by_name['login_url'].containing_oneof = _LOGINRESPONSE.oneofs_by_name['response']
_LOGINRESPONSE.oneofs_by_name['response'].fields.append(
  _LOGINRESPONSE.fields_by_name['refresh_token'])
_LOGINRESPONSE.fields_by_name['refresh_token'].containing_oneof = _LOGINRESPONSE.oneofs_by_name['response']
_GETACTIVEUSERRESPONSE.fields_by_name['user'].message_type = _USERBASICINFO
_DELETEFEATURESETREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_USER.fields_by_name['user_basic_info'].message_type = _USERBASICINFO
_DELETEPROJECTREQUEST.fields_by_name['project'].message_type = _PROJECT
_UPDATEPROJECTMETADATAREQUEST.fields_by_name['project'].message_type = _PROJECT
_CREATEPROJECTRESPONSE.fields_by_name['project'].message_type = _PROJECT
_LISTPROJECTSRESPONSE.fields_by_name['projects'].message_type = _PROJECT
_GETINGESTHISTORYRESPONSE.fields_by_name['ingest_history'].message_type = _FEATURESETINGEST
_LISTFEATURESETSREQUEST.fields_by_name['project'].message_type = _PROJECT
_LISTFEATURESETSREQUEST.fields_by_name['query'].message_type = featurestore_dot_core_dot_FeatureSetSearch__pb2._QUERY
_CREDENTIALS.fields_by_name['aws'].message_type = _AWSCREDENTIALS
_CREDENTIALS.fields_by_name['azure'].message_type = _AZURECREDENTIALS
_CREDENTIALS.fields_by_name['snowflake'].message_type = _SNOWFLAKECREDENTIALS
_CREDENTIALS.fields_by_name['jdbc_database'].message_type = _JDBCCREDENTIALS
_LISTFEATURESETSRESPONSE.fields_by_name['feature_sets'].message_type = _FEATURESET
_LISTFEATURESETVERSIONSRESPONSE.fields_by_name['versions'].message_type = _FEATURESETVERSIONDESCRIPTION
_FEATURESETVERSIONDESCRIPTION.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETFEATURESETREQUEST.fields_by_name['project'].message_type = _PROJECT
_STARTINGESTJOBREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_STARTINGESTJOBREQUEST.fields_by_name['cred'].message_type = _CREDENTIALS
_STARTINGESTJOBREQUEST.fields_by_name['data_source'].message_type = _RAWDATALOCATION
_INGESTRESPONSE_INGESTMETA.fields_by_name['ingestion_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INGESTRESPONSE_INGESTMETA.fields_by_name['ingest_scope'].message_type = _SCOPE
_INGESTRESPONSE_INGESTMETA.containing_type = _INGESTRESPONSE
_INGESTRESPONSE.fields_by_name['meta'].message_type = _INGESTRESPONSE_INGESTMETA
_INGESTRESPONSE.fields_by_name['feature_set'].message_type = _FEATURESET
_RETRIEVEREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_RETRIEVEASLINKSRESPONSE.fields_by_name['retrieve_scope'].message_type = _SCOPE
_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY.containing_type = _RETRIEVEASSPARKRESPONSE
_RETRIEVEASSPARKRESPONSE.fields_by_name['options'].message_type = _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY
_RETRIEVEASSPARKRESPONSE.fields_by_name['retrieve_scope'].message_type = _SCOPE
_PREVIEWREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY.containing_type = _INGESTWRITECREDENTIALRESPONSE
_INGESTWRITECREDENTIALRESPONSE.fields_by_name['options'].message_type = _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY
_RAWDATALOCATION.fields_by_name['csv'].message_type = _CSVFILESPEC
_RAWDATALOCATION.fields_by_name['parquet'].message_type = _PARQUETFILESPEC
_RAWDATALOCATION.fields_by_name['snowflake'].message_type = _SNOWFLAKETABLESPEC
_RAWDATALOCATION.fields_by_name['jdbc'].message_type = _JDBCTABLESPEC
_RAWDATALOCATION.fields_by_name['mojo'].message_type = _DRIVERLESSAIMOJOSPEC
_RAWDATALOCATION.fields_by_name['spark_pipeline'].message_type = _SPARKPIPELINESPEC
_RAWDATALOCATION.fields_by_name['json'].message_type = _JSONFILESPEC
_RAWDATALOCATION.fields_by_name['delta_table'].message_type = _DELTATABLESPEC
_RAWDATALOCATION.fields_by_name['joined_feature_sets'].message_type = _JOINEDFEATURESETSSPEC
_RAWDATALOCATION.fields_by_name['csv_folder'].message_type = _CSVFOLDERSPEC
_RAWDATALOCATION.fields_by_name['parquet_folder'].message_type = _PARQUETFOLDERSPEC
_RAWDATALOCATION.fields_by_name['json_folder'].message_type = _JSONFOLDERSPEC
_RAWDATALOCATION.fields_by_name['temp_parquet'].message_type = _TEMPPARQUETFILESPEC
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['csv'])
_RAWDATALOCATION.fields_by_name['csv'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['parquet'])
_RAWDATALOCATION.fields_by_name['parquet'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['snowflake'])
_RAWDATALOCATION.fields_by_name['snowflake'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['jdbc'])
_RAWDATALOCATION.fields_by_name['jdbc'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['mojo'])
_RAWDATALOCATION.fields_by_name['mojo'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['spark_pipeline'])
_RAWDATALOCATION.fields_by_name['spark_pipeline'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['json'])
_RAWDATALOCATION.fields_by_name['json'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['delta_table'])
_RAWDATALOCATION.fields_by_name['delta_table'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['joined_feature_sets'])
_RAWDATALOCATION.fields_by_name['joined_feature_sets'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['csv_folder'])
_RAWDATALOCATION.fields_by_name['csv_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['parquet_folder'])
_RAWDATALOCATION.fields_by_name['parquet_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['json_folder'])
_RAWDATALOCATION.fields_by_name['json_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['temp_parquet'])
_RAWDATALOCATION.fields_by_name['temp_parquet'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_JOINEDFEATURESETSSPEC.fields_by_name['left'].message_type = _FEATURESET
_JOINEDFEATURESETSSPEC.fields_by_name['right'].message_type = _FEATURESET
_DRIVERLESSAIMOJOSPEC.fields_by_name['input'].message_type = _FEATURESET
_SNOWFLAKETABLESPEC.fields_by_name['proxy'].message_type = _PROXY
_SPARKPIPELINESPEC.fields_by_name['input'].message_type = _FEATURESET
_DELTATABLESPEC.fields_by_name['filter'].message_type = featurestore_dot_core_dot_FeatureSetSearch__pb2._FILTER
_FEATURESET_TIMETOLIVE.containing_type = _FEATURESET
_FEATURESET_STATISTICS.containing_type = _FEATURESET
_FEATURESET_SPECIALDATA_LEGAL.fields_by_name['approved_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET_SPECIALDATA_LEGAL.containing_type = _FEATURESET_SPECIALDATA
_FEATURESET_SPECIALDATA.fields_by_name['legal'].message_type = _FEATURESET_SPECIALDATA_LEGAL
_FEATURESET_SPECIALDATA.containing_type = _FEATURESET
_FEATURESET_ONLINE.containing_type = _FEATURESET
_FEATURESET.fields_by_name['owner'].message_type = _USERBASICINFO
_FEATURESET.fields_by_name['author'].message_type = _USERBASICINFO
_FEATURESET.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['deprecated_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['process_interval_unit'].enum_type = _PROCESSINTERVALUNIT
_FEATURESET.fields_by_name['time_to_live'].message_type = _FEATURESET_TIMETOLIVE
_FEATURESET.fields_by_name['features'].message_type = _FEATURE
_FEATURESET.fields_by_name['statistics'].message_type = _FEATURESET_STATISTICS
_FEATURESET.fields_by_name['special_data'].message_type = _FEATURESET_SPECIALDATA
_FEATURESET.fields_by_name['time_travel_scope'].message_type = _SCOPE
_FEATURESET.fields_by_name['online'].message_type = _FEATURESET_ONLINE
_FEATURESET.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SCOPE.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPE.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REGISTERFEATURESETREQUEST.fields_by_name['project'].message_type = _PROJECT
_REGISTERFEATURESETREQUEST.fields_by_name['schema'].message_type = _FEATURESCHEMA
_REGISTERFEATURESETREQUEST.fields_by_name['online'].message_type = _FEATURESET_ONLINE
_REGISTERFEATURESETREQUEST.fields_by_name['process_interval_unit'].enum_type = _PROCESSINTERVALUNIT
_REGISTERFEATURESETREQUEST.fields_by_name['special_data'].message_type = _FEATURESET_SPECIALDATA
_REGISTERFEATURESETREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['schema'].message_type = _FEATURESCHEMA
_FEATUREPROFILE.fields_by_name['categorical'].message_type = _CATEGORICALFEATURESTATISTICS
_FEATUREPROFILE.fields_by_name['statistics'].message_type = _FEATURESTATISTICS
_FEATURE_MONITORING.containing_type = _FEATURE
_FEATURE.fields_by_name['profile'].message_type = _FEATUREPROFILE
_FEATURE.fields_by_name['monitoring'].message_type = _FEATURE_MONITORING
_FEATURE.fields_by_name['nested_features'].message_type = _FEATURE
_CATEGORICALFEATURESTATISTICS_FEATURETOP.containing_type = _CATEGORICALFEATURESTATISTICS
_CATEGORICALFEATURESTATISTICS.fields_by_name['top'].message_type = _CATEGORICALFEATURESTATISTICS_FEATURETOP
_PROJECT.fields_by_name['owner'].message_type = _USERBASICINFO
_PROJECT.fields_by_name['author'].message_type = _USERBASICINFO
_PROJECT.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROJECT.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESETINGEST.fields_by_name['ingest_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESETINGEST.fields_by_name['source'].message_type = _RAWDATALOCATION
_FEATURESETINGEST.fields_by_name['scope'].message_type = _SCOPE
_PERSONALACCESSTOKEN.fields_by_name['last_used'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERSONALACCESSTOKEN.fields_by_name['creation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERSONALACCESSTOKEN.fields_by_name['expiry_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['FeatureSetExistsRequest'] = _FEATURESETEXISTSREQUEST
DESCRIPTOR.message_types_by_name['GetIngestHistoryRequest'] = _GETINGESTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ProjectExistsRequest'] = _PROJECTEXISTSREQUEST
DESCRIPTOR.message_types_by_name['ExistsResponse'] = _EXISTSRESPONSE
DESCRIPTOR.message_types_by_name['ProjectsDefaultResponse'] = _PROJECTSDEFAULTRESPONSE
DESCRIPTOR.message_types_by_name['HasPermissionToRetrieveRequest'] = _HASPERMISSIONTORETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['HasPermissionToRetrieveResponse'] = _HASPERMISSIONTORETRIEVERESPONSE
DESCRIPTOR.message_types_by_name['StartRevertIngestJobRequest'] = _STARTREVERTINGESTJOBREQUEST
DESCRIPTOR.message_types_by_name['OnlineRetrieveMeta'] = _ONLINERETRIEVEMETA
DESCRIPTOR.message_types_by_name['RefreshTokenRequest'] = _REFRESHTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetUserByMailRequest'] = _GETUSERBYMAILREQUEST
DESCRIPTOR.message_types_by_name['GetUserByMailResponse'] = _GETUSERBYMAILRESPONSE
DESCRIPTOR.message_types_by_name['TokenRequest'] = _TOKENREQUEST
DESCRIPTOR.message_types_by_name['GenerateTokenRequest'] = _GENERATETOKENREQUEST
DESCRIPTOR.message_types_by_name['TokenResponse'] = _TOKENRESPONSE
DESCRIPTOR.message_types_by_name['ListTokensResponse'] = _LISTTOKENSRESPONSE
DESCRIPTOR.message_types_by_name['RawTokenResponse'] = _RAWTOKENRESPONSE
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['JobId'] = _JOBID
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['JobProgressInput'] = _JOBPROGRESSINPUT
DESCRIPTOR.message_types_by_name['JobProgressOutput'] = _JOBPROGRESSOUTPUT
DESCRIPTOR.message_types_by_name['FeatureSetPermissionRequest'] = _FEATURESETPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['ProjectPermissionRequest'] = _PROJECTPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['StartExtractSchemaJobRequest'] = _STARTEXTRACTSCHEMAJOBREQUEST
DESCRIPTOR.message_types_by_name['ExtractSchemaResponse'] = _EXTRACTSCHEMARESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetsVersionRequest'] = _LISTFEATURESETSVERSIONREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetResponse'] = _FEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['ProjectResponse'] = _PROJECTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureSetMetadataRequest'] = _UPDATEFEATURESETMETADATAREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['GetActiveUserResponse'] = _GETACTIVEUSERRESPONSE
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureSetRequest'] = _DELETEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['UserBasicInfo'] = _USERBASICINFO
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['AccessTokenResponse'] = _ACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['DeleteProjectRequest'] = _DELETEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['UpdateProjectMetadataRequest'] = _UPDATEPROJECTMETADATAREQUEST
DESCRIPTOR.message_types_by_name['CreateProjectRequest'] = _CREATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['CreateProjectResponse'] = _CREATEPROJECTRESPONSE
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['GetIngestHistoryResponse'] = _GETINGESTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetsRequest'] = _LISTFEATURESETSREQUEST
DESCRIPTOR.message_types_by_name['AWSCredentials'] = _AWSCREDENTIALS
DESCRIPTOR.message_types_by_name['AzureCredentials'] = _AZURECREDENTIALS
DESCRIPTOR.message_types_by_name['SnowflakeCredentials'] = _SNOWFLAKECREDENTIALS
DESCRIPTOR.message_types_by_name['JDBCCredentials'] = _JDBCCREDENTIALS
DESCRIPTOR.message_types_by_name['Credentials'] = _CREDENTIALS
DESCRIPTOR.message_types_by_name['ListFeatureSetsResponse'] = _LISTFEATURESETSRESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetVersionsResponse'] = _LISTFEATURESETVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSetVersionDescription'] = _FEATURESETVERSIONDESCRIPTION
DESCRIPTOR.message_types_by_name['GetFeatureSetRequest'] = _GETFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['StartIngestJobRequest'] = _STARTINGESTJOBREQUEST
DESCRIPTOR.message_types_by_name['IngestResponse'] = _INGESTRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveRequest'] = _RETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['RetrieveAsLinksResponse'] = _RETRIEVEASLINKSRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveAsSparkResponse'] = _RETRIEVEASSPARKRESPONSE
DESCRIPTOR.message_types_by_name['PreviewRequest'] = _PREVIEWREQUEST
DESCRIPTOR.message_types_by_name['PreviewResponse'] = _PREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['IngestWriteCredentialRequest'] = _INGESTWRITECREDENTIALREQUEST
DESCRIPTOR.message_types_by_name['IngestWriteCredentialResponse'] = _INGESTWRITECREDENTIALRESPONSE
DESCRIPTOR.message_types_by_name['RawDataLocation'] = _RAWDATALOCATION
DESCRIPTOR.message_types_by_name['JoinedFeatureSetsSpec'] = _JOINEDFEATURESETSSPEC
DESCRIPTOR.message_types_by_name['DriverlessAIMOJOSpec'] = _DRIVERLESSAIMOJOSPEC
DESCRIPTOR.message_types_by_name['CSVFileSpec'] = _CSVFILESPEC
DESCRIPTOR.message_types_by_name['JSONFileSpec'] = _JSONFILESPEC
DESCRIPTOR.message_types_by_name['ParquetFileSpec'] = _PARQUETFILESPEC
DESCRIPTOR.message_types_by_name['TempParquetFileSpec'] = _TEMPPARQUETFILESPEC
DESCRIPTOR.message_types_by_name['Proxy'] = _PROXY
DESCRIPTOR.message_types_by_name['SnowflakeTableSpec'] = _SNOWFLAKETABLESPEC
DESCRIPTOR.message_types_by_name['JDBCTableSpec'] = _JDBCTABLESPEC
DESCRIPTOR.message_types_by_name['SparkPipelineSpec'] = _SPARKPIPELINESPEC
DESCRIPTOR.message_types_by_name['DeltaTableSpec'] = _DELTATABLESPEC
DESCRIPTOR.message_types_by_name['CSVFolderSpec'] = _CSVFOLDERSPEC
DESCRIPTOR.message_types_by_name['ParquetFolderSpec'] = _PARQUETFOLDERSPEC
DESCRIPTOR.message_types_by_name['JSONFolderSpec'] = _JSONFOLDERSPEC
DESCRIPTOR.message_types_by_name['FeatureSet'] = _FEATURESET
DESCRIPTOR.message_types_by_name['Scope'] = _SCOPE
DESCRIPTOR.message_types_by_name['RegisterFeatureSetRequest'] = _REGISTERFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['CreateNewFeatureSetVersionRequest'] = _CREATENEWFEATURESETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['FeatureProfile'] = _FEATUREPROFILE
DESCRIPTOR.message_types_by_name['FeatureSchema'] = _FEATURESCHEMA
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['FeatureStatistics'] = _FEATURESTATISTICS
DESCRIPTOR.message_types_by_name['CategoricalFeatureStatistics'] = _CATEGORICALFEATURESTATISTICS
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['FeatureSetIngest'] = _FEATURESETINGEST
DESCRIPTOR.message_types_by_name['PersonalAccessToken'] = _PERSONALACCESSTOKEN
DESCRIPTOR.enum_types_by_name['JobType'] = _JOBTYPE
DESCRIPTOR.enum_types_by_name['PermissionType'] = _PERMISSIONTYPE
DESCRIPTOR.enum_types_by_name['FeatureDataType'] = _FEATUREDATATYPE
DESCRIPTOR.enum_types_by_name['FeatureType'] = _FEATURETYPE
DESCRIPTOR.enum_types_by_name['ProcessIntervalUnit'] = _PROCESSINTERVALUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureSetExistsRequest = _reflection.GeneratedProtocolMessageType('FeatureSetExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETEXISTSREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetExistsRequest)
  })
_sym_db.RegisterMessage(FeatureSetExistsRequest)

GetIngestHistoryRequest = _reflection.GeneratedProtocolMessageType('GetIngestHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINGESTHISTORYREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetIngestHistoryRequest)
  })
_sym_db.RegisterMessage(GetIngestHistoryRequest)

ProjectExistsRequest = _reflection.GeneratedProtocolMessageType('ProjectExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEXISTSREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ProjectExistsRequest)
  })
_sym_db.RegisterMessage(ProjectExistsRequest)

ExistsResponse = _reflection.GeneratedProtocolMessageType('ExistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ExistsResponse)
  })
_sym_db.RegisterMessage(ExistsResponse)

ProjectsDefaultResponse = _reflection.GeneratedProtocolMessageType('ProjectsDefaultResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSDEFAULTRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ProjectsDefaultResponse)
  })
_sym_db.RegisterMessage(ProjectsDefaultResponse)

HasPermissionToRetrieveRequest = _reflection.GeneratedProtocolMessageType('HasPermissionToRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASPERMISSIONTORETRIEVEREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.HasPermissionToRetrieveRequest)
  })
_sym_db.RegisterMessage(HasPermissionToRetrieveRequest)

HasPermissionToRetrieveResponse = _reflection.GeneratedProtocolMessageType('HasPermissionToRetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _HASPERMISSIONTORETRIEVERESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.HasPermissionToRetrieveResponse)
  })
_sym_db.RegisterMessage(HasPermissionToRetrieveResponse)

StartRevertIngestJobRequest = _reflection.GeneratedProtocolMessageType('StartRevertIngestJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTREVERTINGESTJOBREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.StartRevertIngestJobRequest)
  })
_sym_db.RegisterMessage(StartRevertIngestJobRequest)

OnlineRetrieveMeta = _reflection.GeneratedProtocolMessageType('OnlineRetrieveMeta', (_message.Message,), {
  'DESCRIPTOR' : _ONLINERETRIEVEMETA,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.OnlineRetrieveMeta)
  })
_sym_db.RegisterMessage(OnlineRetrieveMeta)

RefreshTokenRequest = _reflection.GeneratedProtocolMessageType('RefreshTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RefreshTokenRequest)
  })
_sym_db.RegisterMessage(RefreshTokenRequest)

GetUserByMailRequest = _reflection.GeneratedProtocolMessageType('GetUserByMailRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERBYMAILREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetUserByMailRequest)
  })
_sym_db.RegisterMessage(GetUserByMailRequest)

GetUserByMailResponse = _reflection.GeneratedProtocolMessageType('GetUserByMailResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERBYMAILRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetUserByMailResponse)
  })
_sym_db.RegisterMessage(GetUserByMailResponse)

TokenRequest = _reflection.GeneratedProtocolMessageType('TokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOKENREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.TokenRequest)
  })
_sym_db.RegisterMessage(TokenRequest)

GenerateTokenRequest = _reflection.GeneratedProtocolMessageType('GenerateTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETOKENREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GenerateTokenRequest)
  })
_sym_db.RegisterMessage(GenerateTokenRequest)

TokenResponse = _reflection.GeneratedProtocolMessageType('TokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOKENRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.TokenResponse)
  })
_sym_db.RegisterMessage(TokenResponse)

ListTokensResponse = _reflection.GeneratedProtocolMessageType('ListTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTOKENSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListTokensResponse)
  })
_sym_db.RegisterMessage(ListTokensResponse)

RawTokenResponse = _reflection.GeneratedProtocolMessageType('RawTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _RAWTOKENRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RawTokenResponse)
  })
_sym_db.RegisterMessage(RawTokenResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

JobId = _reflection.GeneratedProtocolMessageType('JobId', (_message.Message,), {
  'DESCRIPTOR' : _JOBID,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JobId)
  })
_sym_db.RegisterMessage(JobId)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Job)
  })
_sym_db.RegisterMessage(Job)

JobProgressInput = _reflection.GeneratedProtocolMessageType('JobProgressInput', (_message.Message,), {
  'DESCRIPTOR' : _JOBPROGRESSINPUT,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JobProgressInput)
  })
_sym_db.RegisterMessage(JobProgressInput)

JobProgressOutput = _reflection.GeneratedProtocolMessageType('JobProgressOutput', (_message.Message,), {
  'DESCRIPTOR' : _JOBPROGRESSOUTPUT,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JobProgressOutput)
  })
_sym_db.RegisterMessage(JobProgressOutput)

FeatureSetPermissionRequest = _reflection.GeneratedProtocolMessageType('FeatureSetPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETPERMISSIONREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetPermissionRequest)
  })
_sym_db.RegisterMessage(FeatureSetPermissionRequest)

ProjectPermissionRequest = _reflection.GeneratedProtocolMessageType('ProjectPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTPERMISSIONREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ProjectPermissionRequest)
  })
_sym_db.RegisterMessage(ProjectPermissionRequest)

StartExtractSchemaJobRequest = _reflection.GeneratedProtocolMessageType('StartExtractSchemaJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTEXTRACTSCHEMAJOBREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.StartExtractSchemaJobRequest)
  })
_sym_db.RegisterMessage(StartExtractSchemaJobRequest)

ExtractSchemaResponse = _reflection.GeneratedProtocolMessageType('ExtractSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTSCHEMARESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ExtractSchemaResponse)
  })
_sym_db.RegisterMessage(ExtractSchemaResponse)

ListFeatureSetsVersionRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSVERSIONREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListFeatureSetsVersionRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsVersionRequest)

FeatureSetResponse = _reflection.GeneratedProtocolMessageType('FeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetResponse)
  })
_sym_db.RegisterMessage(FeatureSetResponse)

ProjectResponse = _reflection.GeneratedProtocolMessageType('ProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ProjectResponse)
  })
_sym_db.RegisterMessage(ProjectResponse)

UpdateFeatureSetMetadataRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETMETADATAREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.UpdateFeatureSetMetadataRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureSetMetadataRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

GetActiveUserResponse = _reflection.GeneratedProtocolMessageType('GetActiveUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVEUSERRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetActiveUserResponse)
  })
_sym_db.RegisterMessage(GetActiveUserResponse)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

DeleteFeatureSetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.DeleteFeatureSetRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureSetRequest)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.LogoutRequest)
  })
_sym_db.RegisterMessage(LogoutRequest)

UserBasicInfo = _reflection.GeneratedProtocolMessageType('UserBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERBASICINFO,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.UserBasicInfo)
  })
_sym_db.RegisterMessage(UserBasicInfo)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.User)
  })
_sym_db.RegisterMessage(User)

AccessTokenResponse = _reflection.GeneratedProtocolMessageType('AccessTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSTOKENRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.AccessTokenResponse)
  })
_sym_db.RegisterMessage(AccessTokenResponse)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

UpdateProjectMetadataRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTMETADATAREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.UpdateProjectMetadataRequest)
  })
_sym_db.RegisterMessage(UpdateProjectMetadataRequest)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectResponse = _reflection.GeneratedProtocolMessageType('CreateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CreateProjectResponse)
  })
_sym_db.RegisterMessage(CreateProjectResponse)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

GetIngestHistoryResponse = _reflection.GeneratedProtocolMessageType('GetIngestHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINGESTHISTORYRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetIngestHistoryResponse)
  })
_sym_db.RegisterMessage(GetIngestHistoryResponse)

ListFeatureSetsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListFeatureSetsRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsRequest)

AWSCredentials = _reflection.GeneratedProtocolMessageType('AWSCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSCREDENTIALS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.AWSCredentials)
  })
_sym_db.RegisterMessage(AWSCredentials)

AzureCredentials = _reflection.GeneratedProtocolMessageType('AzureCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AZURECREDENTIALS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.AzureCredentials)
  })
_sym_db.RegisterMessage(AzureCredentials)

SnowflakeCredentials = _reflection.GeneratedProtocolMessageType('SnowflakeCredentials', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKECREDENTIALS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.SnowflakeCredentials)
  })
_sym_db.RegisterMessage(SnowflakeCredentials)

JDBCCredentials = _reflection.GeneratedProtocolMessageType('JDBCCredentials', (_message.Message,), {
  'DESCRIPTOR' : _JDBCCREDENTIALS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JDBCCredentials)
  })
_sym_db.RegisterMessage(JDBCCredentials)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), {
  'DESCRIPTOR' : _CREDENTIALS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Credentials)
  })
_sym_db.RegisterMessage(Credentials)

ListFeatureSetsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListFeatureSetsResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetsResponse)

ListFeatureSetVersionsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETVERSIONSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ListFeatureSetVersionsResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetVersionsResponse)

FeatureSetVersionDescription = _reflection.GeneratedProtocolMessageType('FeatureSetVersionDescription', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETVERSIONDESCRIPTION,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetVersionDescription)
  })
_sym_db.RegisterMessage(FeatureSetVersionDescription)

GetFeatureSetRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetFeatureSetRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetRequest)

StartIngestJobRequest = _reflection.GeneratedProtocolMessageType('StartIngestJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINGESTJOBREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.StartIngestJobRequest)
  })
_sym_db.RegisterMessage(StartIngestJobRequest)

IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {

  'IngestMeta' : _reflection.GeneratedProtocolMessageType('IngestMeta', (_message.Message,), {
    'DESCRIPTOR' : _INGESTRESPONSE_INGESTMETA,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.IngestResponse.IngestMeta)
    })
  ,
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)
_sym_db.RegisterMessage(IngestResponse.IngestMeta)

RetrieveRequest = _reflection.GeneratedProtocolMessageType('RetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RetrieveRequest)
  })
_sym_db.RegisterMessage(RetrieveRequest)

RetrieveAsLinksResponse = _reflection.GeneratedProtocolMessageType('RetrieveAsLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEASLINKSRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RetrieveAsLinksResponse)
  })
_sym_db.RegisterMessage(RetrieveAsLinksResponse)

RetrieveAsSparkResponse = _reflection.GeneratedProtocolMessageType('RetrieveAsSparkResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.RetrieveAsSparkResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEASSPARKRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RetrieveAsSparkResponse)
  })
_sym_db.RegisterMessage(RetrieveAsSparkResponse)
_sym_db.RegisterMessage(RetrieveAsSparkResponse.OptionsEntry)

PreviewRequest = _reflection.GeneratedProtocolMessageType('PreviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.PreviewRequest)
  })
_sym_db.RegisterMessage(PreviewRequest)

PreviewResponse = _reflection.GeneratedProtocolMessageType('PreviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.PreviewResponse)
  })
_sym_db.RegisterMessage(PreviewResponse)

IngestWriteCredentialRequest = _reflection.GeneratedProtocolMessageType('IngestWriteCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _INGESTWRITECREDENTIALREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.IngestWriteCredentialRequest)
  })
_sym_db.RegisterMessage(IngestWriteCredentialRequest)

IngestWriteCredentialResponse = _reflection.GeneratedProtocolMessageType('IngestWriteCredentialResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.IngestWriteCredentialResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _INGESTWRITECREDENTIALRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.IngestWriteCredentialResponse)
  })
_sym_db.RegisterMessage(IngestWriteCredentialResponse)
_sym_db.RegisterMessage(IngestWriteCredentialResponse.OptionsEntry)

RawDataLocation = _reflection.GeneratedProtocolMessageType('RawDataLocation', (_message.Message,), {
  'DESCRIPTOR' : _RAWDATALOCATION,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RawDataLocation)
  })
_sym_db.RegisterMessage(RawDataLocation)

JoinedFeatureSetsSpec = _reflection.GeneratedProtocolMessageType('JoinedFeatureSetsSpec', (_message.Message,), {
  'DESCRIPTOR' : _JOINEDFEATURESETSSPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JoinedFeatureSetsSpec)
  })
_sym_db.RegisterMessage(JoinedFeatureSetsSpec)

DriverlessAIMOJOSpec = _reflection.GeneratedProtocolMessageType('DriverlessAIMOJOSpec', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERLESSAIMOJOSPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.DriverlessAIMOJOSpec)
  })
_sym_db.RegisterMessage(DriverlessAIMOJOSpec)

CSVFileSpec = _reflection.GeneratedProtocolMessageType('CSVFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFILESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CSVFileSpec)
  })
_sym_db.RegisterMessage(CSVFileSpec)

JSONFileSpec = _reflection.GeneratedProtocolMessageType('JSONFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _JSONFILESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JSONFileSpec)
  })
_sym_db.RegisterMessage(JSONFileSpec)

ParquetFileSpec = _reflection.GeneratedProtocolMessageType('ParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFILESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ParquetFileSpec)
  })
_sym_db.RegisterMessage(ParquetFileSpec)

TempParquetFileSpec = _reflection.GeneratedProtocolMessageType('TempParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _TEMPPARQUETFILESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.TempParquetFileSpec)
  })
_sym_db.RegisterMessage(TempParquetFileSpec)

Proxy = _reflection.GeneratedProtocolMessageType('Proxy', (_message.Message,), {
  'DESCRIPTOR' : _PROXY,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Proxy)
  })
_sym_db.RegisterMessage(Proxy)

SnowflakeTableSpec = _reflection.GeneratedProtocolMessageType('SnowflakeTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKETABLESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.SnowflakeTableSpec)
  })
_sym_db.RegisterMessage(SnowflakeTableSpec)

JDBCTableSpec = _reflection.GeneratedProtocolMessageType('JDBCTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _JDBCTABLESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JDBCTableSpec)
  })
_sym_db.RegisterMessage(JDBCTableSpec)

SparkPipelineSpec = _reflection.GeneratedProtocolMessageType('SparkPipelineSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPARKPIPELINESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.SparkPipelineSpec)
  })
_sym_db.RegisterMessage(SparkPipelineSpec)

DeltaTableSpec = _reflection.GeneratedProtocolMessageType('DeltaTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _DELTATABLESPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.DeltaTableSpec)
  })
_sym_db.RegisterMessage(DeltaTableSpec)

CSVFolderSpec = _reflection.GeneratedProtocolMessageType('CSVFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFOLDERSPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CSVFolderSpec)
  })
_sym_db.RegisterMessage(CSVFolderSpec)

ParquetFolderSpec = _reflection.GeneratedProtocolMessageType('ParquetFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFOLDERSPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.ParquetFolderSpec)
  })
_sym_db.RegisterMessage(ParquetFolderSpec)

JSONFolderSpec = _reflection.GeneratedProtocolMessageType('JSONFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _JSONFOLDERSPEC,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.JSONFolderSpec)
  })
_sym_db.RegisterMessage(JSONFolderSpec)

FeatureSet = _reflection.GeneratedProtocolMessageType('FeatureSet', (_message.Message,), {

  'TimeToLive' : _reflection.GeneratedProtocolMessageType('TimeToLive', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESET_TIMETOLIVE,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet.TimeToLive)
    })
  ,

  'Statistics' : _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESET_STATISTICS,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet.Statistics)
    })
  ,

  'SpecialData' : _reflection.GeneratedProtocolMessageType('SpecialData', (_message.Message,), {

    'Legal' : _reflection.GeneratedProtocolMessageType('Legal', (_message.Message,), {
      'DESCRIPTOR' : _FEATURESET_SPECIALDATA_LEGAL,
      '__module__' : 'featurestore.core.CoreService_pb2'
      # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet.SpecialData.Legal)
      })
    ,
    'DESCRIPTOR' : _FEATURESET_SPECIALDATA,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet.SpecialData)
    })
  ,

  'Online' : _reflection.GeneratedProtocolMessageType('Online', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESET_ONLINE,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet.Online)
    })
  ,
  'DESCRIPTOR' : _FEATURESET,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSet)
  })
_sym_db.RegisterMessage(FeatureSet)
_sym_db.RegisterMessage(FeatureSet.TimeToLive)
_sym_db.RegisterMessage(FeatureSet.Statistics)
_sym_db.RegisterMessage(FeatureSet.SpecialData)
_sym_db.RegisterMessage(FeatureSet.SpecialData.Legal)
_sym_db.RegisterMessage(FeatureSet.Online)

Scope = _reflection.GeneratedProtocolMessageType('Scope', (_message.Message,), {
  'DESCRIPTOR' : _SCOPE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Scope)
  })
_sym_db.RegisterMessage(Scope)

RegisterFeatureSetRequest = _reflection.GeneratedProtocolMessageType('RegisterFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERFEATURESETREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.RegisterFeatureSetRequest)
  })
_sym_db.RegisterMessage(RegisterFeatureSetRequest)

CreateNewFeatureSetVersionRequest = _reflection.GeneratedProtocolMessageType('CreateNewFeatureSetVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENEWFEATURESETVERSIONREQUEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CreateNewFeatureSetVersionRequest)
  })
_sym_db.RegisterMessage(CreateNewFeatureSetVersionRequest)

FeatureProfile = _reflection.GeneratedProtocolMessageType('FeatureProfile', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPROFILE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureProfile)
  })
_sym_db.RegisterMessage(FeatureProfile)

FeatureSchema = _reflection.GeneratedProtocolMessageType('FeatureSchema', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESCHEMA,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSchema)
  })
_sym_db.RegisterMessage(FeatureSchema)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {

  'Monitoring' : _reflection.GeneratedProtocolMessageType('Monitoring', (_message.Message,), {
    'DESCRIPTOR' : _FEATURE_MONITORING,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.Feature.Monitoring)
    })
  ,
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Feature)
  })
_sym_db.RegisterMessage(Feature)
_sym_db.RegisterMessage(Feature.Monitoring)

FeatureStatistics = _reflection.GeneratedProtocolMessageType('FeatureStatistics', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTATISTICS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureStatistics)
  })
_sym_db.RegisterMessage(FeatureStatistics)

CategoricalFeatureStatistics = _reflection.GeneratedProtocolMessageType('CategoricalFeatureStatistics', (_message.Message,), {

  'FeatureTop' : _reflection.GeneratedProtocolMessageType('FeatureTop', (_message.Message,), {
    'DESCRIPTOR' : _CATEGORICALFEATURESTATISTICS_FEATURETOP,
    '__module__' : 'featurestore.core.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:featurestore.core.CategoricalFeatureStatistics.FeatureTop)
    })
  ,
  'DESCRIPTOR' : _CATEGORICALFEATURESTATISTICS,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.CategoricalFeatureStatistics)
  })
_sym_db.RegisterMessage(CategoricalFeatureStatistics)
_sym_db.RegisterMessage(CategoricalFeatureStatistics.FeatureTop)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONRESPONSE,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.GetVersionResponse)
  })
_sym_db.RegisterMessage(GetVersionResponse)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.Project)
  })
_sym_db.RegisterMessage(Project)

FeatureSetIngest = _reflection.GeneratedProtocolMessageType('FeatureSetIngest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETINGEST,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.FeatureSetIngest)
  })
_sym_db.RegisterMessage(FeatureSetIngest)

PersonalAccessToken = _reflection.GeneratedProtocolMessageType('PersonalAccessToken', (_message.Message,), {
  'DESCRIPTOR' : _PERSONALACCESSTOKEN,
  '__module__' : 'featurestore.core.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:featurestore.core.PersonalAccessToken)
  })
_sym_db.RegisterMessage(PersonalAccessToken)


DESCRIPTOR._options = None
_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._options = None
_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._options = None

_CORESERVICE = _descriptor.ServiceDescriptor(
  name='CoreService',
  full_name='featurestore.core.CoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=13470,
  serialized_end=17945,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListJobs',
    full_name='featurestore.core.CoreService.ListJobs',
    index=0,
    containing_service=None,
    input_type=_LISTJOBSREQUEST,
    output_type=_LISTJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJob',
    full_name='featurestore.core.CoreService.GetJob',
    index=1,
    containing_service=None,
    input_type=_JOBID,
    output_type=_JOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobProgress',
    full_name='featurestore.core.CoreService.GetJobProgress',
    index=2,
    containing_service=None,
    input_type=_JOBPROGRESSINPUT,
    output_type=_JOBPROGRESSOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartExtractSchemaJob',
    full_name='featurestore.core.CoreService.StartExtractSchemaJob',
    index=3,
    containing_service=None,
    input_type=_STARTEXTRACTSCHEMAJOBREQUEST,
    output_type=_JOBID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtractSchemaJobOutput',
    full_name='featurestore.core.CoreService.GetExtractSchemaJobOutput',
    index=4,
    containing_service=None,
    input_type=_JOBID,
    output_type=_EXTRACTSCHEMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartIngestJob',
    full_name='featurestore.core.CoreService.StartIngestJob',
    index=5,
    containing_service=None,
    input_type=_STARTINGESTJOBREQUEST,
    output_type=_JOBID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestJobOutput',
    full_name='featurestore.core.CoreService.GetIngestJobOutput',
    index=6,
    containing_service=None,
    input_type=_JOBID,
    output_type=_INGESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRetrieveAsLinksJob',
    full_name='featurestore.core.CoreService.StartRetrieveAsLinksJob',
    index=7,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_JOBID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRetrieveAsLinksJobOutput',
    full_name='featurestore.core.CoreService.GetRetrieveAsLinksJobOutput',
    index=8,
    containing_service=None,
    input_type=_JOBID,
    output_type=_RETRIEVEASLINKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveAsSpark',
    full_name='featurestore.core.CoreService.RetrieveAsSpark',
    index=9,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_RETRIEVEASSPARKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartPreviewJob',
    full_name='featurestore.core.CoreService.StartPreviewJob',
    index=10,
    containing_service=None,
    input_type=_PREVIEWREQUEST,
    output_type=_JOBID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPreviewJobOutput',
    full_name='featurestore.core.CoreService.GetPreviewJobOutput',
    index=11,
    containing_service=None,
    input_type=_JOBID,
    output_type=_PREVIEWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestWriteCredentials',
    full_name='featurestore.core.CoreService.GetIngestWriteCredentials',
    index=12,
    containing_service=None,
    input_type=_INGESTWRITECREDENTIALREQUEST,
    output_type=_INGESTWRITECREDENTIALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRevertIngestJob',
    full_name='featurestore.core.CoreService.StartRevertIngestJob',
    index=13,
    containing_service=None,
    input_type=_STARTREVERTINGESTJOBREQUEST,
    output_type=_JOBID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRevertIngestJobOutput',
    full_name='featurestore.core.CoreService.GetRevertIngestJobOutput',
    index=14,
    containing_service=None,
    input_type=_JOBID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HasPermissionToRetrieve',
    full_name='featurestore.core.CoreService.HasPermissionToRetrieve',
    index=15,
    containing_service=None,
    input_type=_HASPERMISSIONTORETRIEVEREQUEST,
    output_type=_HASPERMISSIONTORETRIEVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterFeatureSet',
    full_name='featurestore.core.CoreService.RegisterFeatureSet',
    index=16,
    containing_service=None,
    input_type=_REGISTERFEATURESETREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNewFeatureSetVersion',
    full_name='featurestore.core.CoreService.CreateNewFeatureSetVersion',
    index=17,
    containing_service=None,
    input_type=_CREATENEWFEATURESETVERSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnlineRetrieveMeta',
    full_name='featurestore.core.CoreService.GetOnlineRetrieveMeta',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ONLINERETRIEVEMETA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetMetadata',
    full_name='featurestore.core.CoreService.UpdateFeatureSetMetadata',
    index=19,
    containing_service=None,
    input_type=_UPDATEFEATURESETMETADATAREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='featurestore.core.CoreService.GetVersion',
    index=20,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETVERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSet',
    full_name='featurestore.core.CoreService.GetFeatureSet',
    index=21,
    containing_service=None,
    input_type=_GETFEATURESETREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureSetVersions',
    full_name='featurestore.core.CoreService.ListFeatureSetVersions',
    index=22,
    containing_service=None,
    input_type=_LISTFEATURESETSVERSIONREQUEST,
    output_type=_LISTFEATURESETVERSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureSet',
    full_name='featurestore.core.CoreService.DeleteFeatureSet',
    index=23,
    containing_service=None,
    input_type=_DELETEFEATURESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureSets',
    full_name='featurestore.core.CoreService.ListFeatureSets',
    index=24,
    containing_service=None,
    input_type=_LISTFEATURESETSREQUEST,
    output_type=_LISTFEATURESETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureSetExists',
    full_name='featurestore.core.CoreService.FeatureSetExists',
    index=25,
    containing_service=None,
    input_type=_FEATURESETEXISTSREQUEST,
    output_type=_EXISTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestHistory',
    full_name='featurestore.core.CoreService.GetIngestHistory',
    index=26,
    containing_service=None,
    input_type=_GETINGESTHISTORYREQUEST,
    output_type=_GETINGESTHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProjects',
    full_name='featurestore.core.CoreService.ListProjects',
    index=27,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTPROJECTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProject',
    full_name='featurestore.core.CoreService.CreateProject',
    index=28,
    containing_service=None,
    input_type=_CREATEPROJECTREQUEST,
    output_type=_CREATEPROJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProject',
    full_name='featurestore.core.CoreService.GetProject',
    index=29,
    containing_service=None,
    input_type=_GETPROJECTREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProject',
    full_name='featurestore.core.CoreService.DeleteProject',
    index=30,
    containing_service=None,
    input_type=_DELETEPROJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectMetadata',
    full_name='featurestore.core.CoreService.UpdateProjectMetadata',
    index=31,
    containing_service=None,
    input_type=_UPDATEPROJECTMETADATAREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProjectsDefault',
    full_name='featurestore.core.CoreService.GetProjectsDefault',
    index=32,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PROJECTSDEFAULTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProjectExists',
    full_name='featurestore.core.CoreService.ProjectExists',
    index=33,
    containing_service=None,
    input_type=_PROJECTEXISTSREQUEST,
    output_type=_EXISTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccessToken',
    full_name='featurestore.core.CoreService.GetAccessToken',
    index=34,
    containing_service=None,
    input_type=_REFRESHTOKENREQUEST,
    output_type=_ACCESSTOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserByMail',
    full_name='featurestore.core.CoreService.GetUserByMail',
    index=35,
    containing_service=None,
    input_type=_GETUSERBYMAILREQUEST,
    output_type=_GETUSERBYMAILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='featurestore.core.CoreService.Logout',
    index=36,
    containing_service=None,
    input_type=_LOGOUTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveUser',
    full_name='featurestore.core.CoreService.GetActiveUser',
    index=37,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETACTIVEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='featurestore.core.CoreService.Login',
    index=38,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LOGINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddFeatureSetPermission',
    full_name='featurestore.core.CoreService.AddFeatureSetPermission',
    index=39,
    containing_service=None,
    input_type=_FEATURESETPERMISSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddProjectPermission',
    full_name='featurestore.core.CoreService.AddProjectPermission',
    index=40,
    containing_service=None,
    input_type=_PROJECTPERMISSIONREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveFeatureSetPermission',
    full_name='featurestore.core.CoreService.RemoveFeatureSetPermission',
    index=41,
    containing_service=None,
    input_type=_FEATURESETPERMISSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveProjectPermission',
    full_name='featurestore.core.CoreService.RemoveProjectPermission',
    index=42,
    containing_service=None,
    input_type=_PROJECTPERMISSIONREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeToken',
    full_name='featurestore.core.CoreService.RevokeToken',
    index=43,
    containing_service=None,
    input_type=_TOKENREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateToken',
    full_name='featurestore.core.CoreService.GenerateToken',
    index=44,
    containing_service=None,
    input_type=_GENERATETOKENREQUEST,
    output_type=_RAWTOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTokens',
    full_name='featurestore.core.CoreService.ListTokens',
    index=45,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTTOKENSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetToken',
    full_name='featurestore.core.CoreService.GetToken',
    index=46,
    containing_service=None,
    input_type=_TOKENREQUEST,
    output_type=_TOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORESERVICE)

DESCRIPTOR.services_by_name['CoreService'] = _CORESERVICE

# @@protoc_insertion_point(module_scope)
